@@ -31,6 +31,16 @@ import java.awt.Image;
 import java.awt.Insets;
 import java.awt.Point;
 import java.awt.Window;
+import java.awt.desktop.AboutEvent;
+import java.awt.desktop.AboutHandler;
+import java.awt.desktop.OpenFilesEvent;
+import java.awt.desktop.OpenFilesHandler;
+import java.awt.desktop.PreferencesEvent;
+import java.awt.desktop.PreferencesHandler;
+import java.awt.desktop.QuitEvent;
+import java.awt.desktop.QuitHandler;
+import java.awt.desktop.QuitResponse;
+import java.awt.desktop.QuitStrategy;
 import java.awt.event.ActionEvent;
 import java.awt.event.MouseEvent;
 import java.awt.event.WindowAdapter;
@@ -174,41 +184,48 @@ class MacOSXConfiguration {
     if (!applicationListenerSupported) {
       // Probably running under Java 9 where previous methods were removed
       if (OperatingSystem.isJavaVersionGreaterOrEqual("1.9")) {
-        // Use the new handlers of Java 9 once compiling with Java 9 library is enabled
-        /*
-        java.awt.Desktop.getDesktop().setQuitHandler(new java.awt.desktop.QuitHandler() {
-            public void handleQuitRequestWith(java.awt.desktop.QuitEvent ev, java.awt.desktop.QuitResponse answer) {
-              MacOSXConfiguration.handleQuit(homeApplication, defaultController, defaultFrame);
-            }
-          });
-        java.awt.Desktop.getDesktop().setAboutHandler(new java.awt.desktop.AboutHandler() {
-            public void handleAbout(java.awt.desktop.AboutEvent ev) {
-              MacOSXConfiguration.handleAbout(homeApplication, defaultController, defaultFrame);
-            }
-          });
-        java.awt.Desktop.getDesktop().setPreferencesHandler(new java.awt.desktop.PreferencesHandler() {
-            public void handlePreferences(java.awt.desktop.PreferencesEvent ev) {
-              MacOSXConfiguration.handlePreferences(homeApplication, defaultController, defaultFrame);
-            }
-          });
-        java.awt.Desktop.getDesktop().setOpenFileHandler(new java.awt.desktop.OpenFilesHandler() {
-            public void openFiles(java.awt.desktop.OpenFilesEvent ev) {
-              for (java.io.File file : ev.getFiles()) {
-                MacOSXConfiguration.handleOpenFile(homeApplication, file.getAbsolutePath());
-              }
-            }
-          });
-        */
         try {
-          // Call Desktop.getDesktop().setQuitStrategy(QuitStrategy.CLOSE_ALL_WINDOWS)
-          // to prevent default call to System#exit
+          // Instantiate Java 9 handlers and set them on desktop by reflection
           Class<?> desktopClass = Class.forName("java.awt.Desktop");
           Object desktopInstance = desktopClass.getMethod("getDesktop").invoke(null);
-          Class<?> quitStrategyEnum = Class.forName("java.awt.desktop.QuitStrategy");
-          desktopClass.getMethod("setQuitStrategy", quitStrategyEnum).invoke(
-              desktopInstance, quitStrategyEnum.getField("CLOSE_ALL_WINDOWS").get(null));
-        } catch (Exception ex2) {
-          ex2.printStackTrace();
+
+          Object quitHandler = new QuitHandler() {
+              public void handleQuitRequestWith(QuitEvent ev, QuitResponse answer) {
+                MacOSXConfiguration.handleQuit(homeApplication, defaultController, defaultFrame);
+                answer.cancelQuit();
+              }
+            };
+          desktopClass.getMethod("setQuitHandler", QuitHandler.class).invoke(desktopInstance, quitHandler);
+
+          Object aboutHandler = new AboutHandler() {
+              public void handleAbout(AboutEvent ev) {
+                MacOSXConfiguration.handleAbout(homeApplication, defaultController, defaultFrame);
+              }
+            };
+          desktopClass.getMethod("setAboutHandler", AboutHandler.class).invoke(desktopInstance, aboutHandler);
+
+          Object preferencesHandler = new PreferencesHandler() {
+              public void handlePreferences(PreferencesEvent ev) {
+                MacOSXConfiguration.handlePreferences(homeApplication, defaultController, defaultFrame);
+              }
+            };
+          desktopClass.getMethod("setPreferencesHandler", PreferencesHandler.class).invoke(desktopInstance, preferencesHandler);
+
+          Object openFilesHandler = new OpenFilesHandler() {
+              public void openFiles(OpenFilesEvent ev) {
+                for (java.io.File file : ev.getFiles()) {
+                  MacOSXConfiguration.handleOpenFile(homeApplication, file.getAbsolutePath());
+                }
+              }
+            };
+          desktopClass.getMethod("setOpenFileHandler", OpenFilesHandler.class).invoke(desktopInstance, openFilesHandler);
+
+          // Call Desktop.getDesktop().setQuitStrategy(QuitStrategy.CLOSE_ALL_WINDOWS) to prevent default call to System#exit
+          desktopClass.getMethod("setQuitStrategy", QuitStrategy.class).invoke(desktopInstance, QuitStrategy.CLOSE_ALL_WINDOWS);
+        } catch (NoSuchMethodException ex) {
+        } catch (IllegalAccessException ex) {
+        } catch (InvocationTargetException ex) {
+        } catch (ClassNotFoundException ex) {
         }
       }
     }
