@@ -108,6 +108,7 @@ public class FileUserPreferences extends UserPreferences {
   private static final String NEW_WALL_HEIGHT                           = "newHomeWallHeight";
   private static final String NEW_WALL_BASEBOARD_THICKNESS              = "newWallBaseboardThickness";
   private static final String NEW_WALL_BASEBOARD_HEIGHT                 = "newWallBaseboardHeight";
+  private static final String NEW_ROOM_FLOOR_COLOR                      = "newRoomFloorColor";
   private static final String NEW_FLOOR_THICKNESS                       = "newFloorThickness";
   private static final String CHECK_UPDATES_ENABLED                     = "checkUpdatesEnabled";
   private static final String UPDATES_MINIMUM_DATE                      = "updatesMinimumDate";
@@ -337,6 +338,12 @@ public class FileUserPreferences extends UserPreferences {
         defaultPreferences.getNewWallBaseboardThickness()));
     setNewWallBaseboardHeight(preferences.getFloat(NEW_WALL_BASEBOARD_HEIGHT,
         defaultPreferences.getNewWallBaseboardHeight()));
+    String newRoomFloorColor = preferences.get(NEW_ROOM_FLOOR_COLOR, null);
+    if (newRoomFloorColor != null) {
+      setNewRoomFloorColor(Integer.decode(newRoomFloorColor) | 0xFF000000);
+    } else {
+      setNewRoomFloorColor(defaultPreferences.getNewRoomFloorColor());
+    }
     setNewFloorThickness(preferences.getFloat(NEW_FLOOR_THICKNESS,
         defaultPreferences.getNewFloorThickness()));
     setCheckUpdatesEnabled(preferences.getBoolean(CHECK_UPDATES_ENABLED,
@@ -972,6 +979,12 @@ public class FileUserPreferences extends UserPreferences {
     preferences.putFloat(NEW_WALL_HEIGHT, getNewWallHeight());
     preferences.putFloat(NEW_WALL_BASEBOARD_THICKNESS, getNewWallBaseboardThickness());
     preferences.putFloat(NEW_WALL_BASEBOARD_HEIGHT, getNewWallBaseboardHeight());
+    Integer newRoomFloorColor = getNewRoomFloorColor();
+    if (newRoomFloorColor != null) {
+      preferences.put(NEW_ROOM_FLOOR_COLOR, String.format("#%6X", newRoomFloorColor & 0xFFFFFF).replace(' ', '0'));
+    } else {
+      preferences.remove(NEW_ROOM_FLOOR_COLOR);
+    }
     preferences.putFloat(NEW_FLOOR_THICKNESS, getNewFloorThickness());
     preferences.putBoolean(CHECK_UPDATES_ENABLED, isCheckUpdatesEnabled());
     Long updatesMinimumDate = getUpdatesMinimumDate();
