@@ -69,6 +69,7 @@ import com.eteks.sweethome3d.model.Transformation;
 import com.eteks.sweethome3d.model.UserPreferences;
 import com.eteks.sweethome3d.model.Wall;
 import com.eteks.sweethome3d.tools.ResourceURLContent;
+import com.eteks.sweethome3d.tools.URLContent;
 
 /**
  * SAX handler for Sweet Home 3D XML stream. Read home should respect the following DTD:<pre>
@@ -92,7 +93,7 @@ import com.eteks.sweethome3d.tools.ResourceURLContent;
  * &lt;!ELEMENT furnitureVisibleProperty EMPTY>
  * &lt;!ATTLIST furnitureVisibleProperty name CDATA #REQUIRED>
  *
- * &lt;!ELEMENT environment ((camera | observerCamera)*, texture?, texture?) >
+ * &lt;!ELEMENT environment (property*, (camera | observerCamera)*, texture?, texture?) >
  * &lt;!ATTLIST environment
  *       groundColor CDATA #IMPLIED
  *       backgroundImageVisibleOnGround3D (false | true) "false"
@@ -154,7 +155,8 @@ import com.eteks.sweethome3d.tools.ResourceURLContent;
  *       visible (false | true) "true">
  *
  * &lt;!ENTITY % cameraCommonAttributes
- *      'name CDATA #IMPLIED
+ *      'id ID #IMPLIED
+ *       name CDATA #IMPLIED
  *       lens (PINHOLE | NORMAL | FISHEYE | SPHERICAL) "PINHOLE"
  *       x CDATA #REQUIRED
  *       y CDATA #REQUIRED
@@ -187,7 +189,8 @@ import com.eteks.sweethome3d.tools.ResourceURLContent;
  *       viewable (false | true) "true">
  *
  * &lt;!ENTITY % furnitureCommonAttributes
- *      'name CDATA #REQUIRED
+ *      'id ID #IMPLIED
+ *       name CDATA #REQUIRED
  *       angle CDATA "0"
  *       visible (false | true) "true"
  *       movable (false | true) "true"
@@ -358,6 +361,7 @@ import com.eteks.sweethome3d.tools.ResourceURLContent;
  *
  * &lt;!ELEMENT room (property*, textStyle?, textStyle?, texture?, texture?, point+)>
  * &lt;!ATTLIST room
+ *       id ID #IMPLIED
  *       level IDREF #IMPLIED
  *       name CDATA #IMPLIED
  *       nameAngle CDATA "0"
@@ -381,6 +385,7 @@ import com.eteks.sweethome3d.tools.ResourceURLContent;
  *
  * &lt;!ELEMENT polyline (property*, point+)>
  * &lt;!ATTLIST polyline
+ *       id ID #IMPLIED
  *       level IDREF #IMPLIED
  *       thickness CDATA "1"
  *       capStyle (BUTT | SQUARE | ROUND) "BUTT"
@@ -396,6 +401,7 @@ import com.eteks.sweethome3d.tools.ResourceURLContent;
  *
  * &lt;!ELEMENT dimensionLine (property*, textStyle?)>
  * &lt;!ATTLIST dimensionLine
+ *       id ID #IMPLIED
  *       level IDREF #IMPLIED
  *       xStart CDATA #REQUIRED
  *       yStart CDATA #REQUIRED
@@ -405,6 +411,7 @@ import com.eteks.sweethome3d.tools.ResourceURLContent;
  *
  * &lt;!ELEMENT label (property*, textStyle?, text)>
  * &lt;!ATTLIST label
+ *       id ID #IMPLIED
  *       level IDREF #IMPLIED
  *       x CDATA #REQUIRED
  *       y CDATA #REQUIRED
@@ -770,13 +777,15 @@ public class HomeXMLHandler extends DefaultHandler {
     // Rebind wall starts and ends
     for (JoinedWall joinedWall : this.joinedWalls.values()) {
       Wall wall = joinedWall.getWall();
-      if (joinedWall.getWallAtStartId() != null) {
+      if (joinedWall.getWallAtStartId() != null
+          && !joinedWall.getWallAtStartId().equals(wall.getId())) { // Check wall doesn't point to itself (bug in version 6.4)
         JoinedWall joinedWallAtStart = this.joinedWalls.get(joinedWall.getWallAtStartId());
         if (joinedWallAtStart != null) {
           wall.setWallAtStart(joinedWallAtStart.getWall());
         }
       }
-      if (joinedWall.getWallAtEndId() != null) {
+      if (joinedWall.getWallAtEndId() != null
+          && !joinedWall.getWallAtEndId().equals(wall.getId())) { // Check wall doesn't point to itself (bug in version 6.4)
         JoinedWall joinedWallAtEnd = this.joinedWalls.get(joinedWall.getWallAtEndId());
         if (joinedWallAtEnd != null) {
           wall.setWallAtEnd(joinedWallAtEnd.getWall());
@@ -858,6 +867,7 @@ public class HomeXMLHandler extends DefaultHandler {
   private void setEnvironmentAttributes(HomeEnvironment environment,
                                         String elementName,
                                         Map<String, String> attributes) throws SAXException {
+    setProperties(environment);
     Integer groundColor = parseOptionalColor(attributes, "groundColor");
     if (groundColor != null) {
       environment.setGroundColor(groundColor);
@@ -1004,21 +1014,22 @@ public class HomeXMLHandler extends DefaultHandler {
    * Returns a new {@link Camera} instance initialized from the given <code>attributes</code>.
    */
   private Camera createCamera(String elementName, Map<String, String> attributes) throws SAXException {
+    String id = attributes.get("id");
+    float x = parseFloat(attributes, "x");
+    float y = parseFloat(attributes, "y");
+    float z = parseFloat(attributes, "z");
+    float yaw = parseFloat(attributes, "yaw");
+    float pitch = parseFloat(attributes, "pitch");
+    float fieldOfView = parseFloat(attributes, "fieldOfView");
     Camera camera;
     if ("observerCamera".equals(elementName)) {
-      camera = new ObserverCamera(parseFloat(attributes, "x"),
-          parseFloat(attributes, "y"),
-          parseFloat(attributes, "z"),
-          parseFloat(attributes, "yaw"),
-          parseFloat(attributes, "pitch"),
-          parseFloat(attributes, "fieldOfView"));
+      camera = id != null
+          ? new ObserverCamera(id, x, y, z, yaw, pitch, fieldOfView)
+          : new ObserverCamera(x, y, z, yaw, pitch, fieldOfView);
     } else {
-      camera = new Camera(parseFloat(attributes, "x"),
-          parseFloat(attributes, "y"),
-          parseFloat(attributes, "z"),
-          parseFloat(attributes, "yaw"),
-          parseFloat(attributes, "pitch"),
-          parseFloat(attributes, "fieldOfView"));
+      camera = id != null
+          ? new Camera(id, x, y, z, yaw, pitch, fieldOfView)
+          : new Camera(x, y, z, yaw, pitch, fieldOfView);
     }
     return (Camera)resolveObject(camera, elementName, attributes);
   }
@@ -1058,10 +1069,14 @@ public class HomeXMLHandler extends DefaultHandler {
    * Returns a new {@link Level} instance initialized from the given <code>attributes</code>.
    */
   private Level createLevel(String elementName, Map<String, String> attributes) throws SAXException {
-    Level level = new Level(attributes.get("name"),
-        parseFloat(attributes, "elevation"),
-        parseFloat(attributes, "floorThickness"),
-        parseFloat(attributes, "height"));
+    String id = attributes.get("id");
+    String name = attributes.get("name");
+    float elevation = parseFloat(attributes, "elevation");
+    float floorThickness = parseFloat(attributes, "floorThickness");
+    float height = parseFloat(attributes, "height");
+    Level level = id != null
+        ? new Level(id, name, elevation, floorThickness, height)
+        : new Level(name, elevation, floorThickness, height);
     return (Level)resolveObject(level, elementName, attributes);
   }
 
@@ -1086,6 +1101,7 @@ public class HomeXMLHandler extends DefaultHandler {
    * Returns a new {@link HomePieceOfFurniture} instance initialized from the given <code>attributes</code>.
    */
   private HomePieceOfFurniture createPieceOfFurniture(String elementName, Map<String, String> attributes) throws SAXException {
+    String id = attributes.get("id");
     String catalogId = attributes.get("catalogId");
     String [] tags = attributes.get("tags") != null
         ? attributes.get("tags").split(" ")
@@ -1117,6 +1133,27 @@ public class HomeXMLHandler extends DefaultHandler {
         throw new SAXException("Invalid value for attribute modelRotation", ex);
       }
     }
+    String name = attributes.get("name");
+    String description = attributes.get("description");
+    String information = attributes.get("information");
+    Long creationDate = parseOptionalLong(attributes, "creationDate");
+    Float grade = parseOptionalFloat(attributes, "grade");
+    Content icon = parseContent(attributes.get("icon"), catalogId, false);
+    Content planIcon = parseContent(attributes.get("planIcon"), catalogId, false);
+    Content model = parseContent(attributes.get("model"), catalogId, false);
+    float width = parseFloat(attributes, "width");
+    float depth = parseFloat(attributes, "depth");
+    float height = parseFloat(attributes, "height");
+    boolean movable = !"false".equals(attributes.get("movable"));
+    boolean backFaceShown = "true".equals(attributes.get("backFaceShown"));
+    Long modelSize = parseOptionalLong(attributes, "modelSize");
+    String creator = attributes.get("creator");
+    boolean resizable = !"false".equals(attributes.get("resizable"));
+    boolean deformable = !"false".equals(attributes.get("deformable"));
+    boolean texturable = !"false".equals(attributes.get("texturable"));
+    BigDecimal price = parseOptionalDecimal(attributes, "price");
+    BigDecimal valueAddedTaxPercentage = parseOptionalDecimal(attributes, "valueAddedTaxPercentage");
+    String currency = attributes.get("currency");
     HomePieceOfFurniture piece;
     if ("doorOrWindow".equals(elementName)
         // Replace old HomePieceOfFurniture instances with doorOrWindow attribute set to true by HomeDoorOrWindow instances
@@ -1133,100 +1170,38 @@ public class HomeXMLHandler extends DefaultHandler {
         // Set default cut out shape set on old HomePieceOfFurniture instances with doorOrWindow attribute set to true
         cutOutShape = PieceOfFurniture.DEFAULT_CUT_OUT_SHAPE;
       }
-      piece = new HomeDoorOrWindow(new CatalogDoorOrWindow(
-          catalogId,
-          attributes.get("name"),
-          attributes.get("description"),
-          attributes.get("information"),
-          tags,
-          parseOptionalLong(attributes, "creationDate"),
-          parseOptionalFloat(attributes, "grade"),
-          parseContent(attributes.get("icon"), catalogId, false),
-          parseContent(attributes.get("planIcon"), catalogId, false),
-          parseContent(attributes.get("model"), catalogId, false),
-          parseFloat(attributes, "width"),
-          parseFloat(attributes, "depth"),
-          parseFloat(attributes, "height"),
-          elevation,
-          dropOnTopElevation,
-          !"false".equals(attributes.get("movable")),
-          cutOutShape,
-          wallThickness,
-          wallDistance,
-          "true".equals(attributes.get("wallCutOutOnBothSides")),
-          !"false".equals(attributes.get("widthDepthDeformable")),
+      boolean wallCutOutOnBothSides = "true".equals(attributes.get("wallCutOutOnBothSides"));
+      boolean widthDepthDeformable = !"false".equals(attributes.get("widthDepthDeformable"));
+      CatalogDoorOrWindow catalogDoorOrWindow = new CatalogDoorOrWindow(catalogId, name, description, information, tags,
+          creationDate, grade, icon, planIcon, model, width, depth, height, elevation, dropOnTopElevation, movable,
+          cutOutShape, wallThickness, wallDistance, wallCutOutOnBothSides, widthDepthDeformable,
           this.sashes.toArray(new Sash [this.sashes.size()]),
-          modelRotation,
-          "true".equals(attributes.get("backFaceShown")),
-          parseOptionalLong(attributes, "modelSize"),
-          attributes.get("creator"),
-          !"false".equals(attributes.get("resizable")),
-          !"false".equals(attributes.get("deformable")),
-          !"false".equals(attributes.get("texturable")),
-          parseOptionalDecimal(attributes, "price"),
-          parseOptionalDecimal(attributes, "valueAddedTaxPercentage"),
-          attributes.get("currency")));
-    } else if ("light".equals(elementName)) {
-      piece = new HomeLight(new CatalogLight(
-          catalogId,
-          attributes.get("name"),
-          attributes.get("description"),
-          attributes.get("information"),
-          tags,
-          parseOptionalLong(attributes, "creationDate"),
-          parseOptionalFloat(attributes, "grade"),
-          parseContent(attributes.get("icon"), catalogId, false),
-          parseContent(attributes.get("planIcon"), catalogId, false),
-          parseContent(attributes.get("model"), catalogId, false),
-          parseFloat(attributes, "width"),
-          parseFloat(attributes, "depth"),
-          parseFloat(attributes, "height"),
-          elevation,
-          dropOnTopElevation,
-          !"false".equals(attributes.get("movable")),
-          this.lightSources.toArray(new LightSource [this.lightSources.size()]),
-          attributes.get("staircaseCutOutShape"),
-          modelRotation,
-          "true".equals(attributes.get("backFaceShown")),
-          parseOptionalLong(attributes, "modelSize"),
-          attributes.get("creator"),
-          !"false".equals(attributes.get("resizable")),
-          !"false".equals(attributes.get("deformable")),
-          !"false".equals(attributes.get("texturable")),
-          !"false".equals(attributes.get("horizontallyRotatable")),
-          parseOptionalDecimal(attributes, "price"),
-          parseOptionalDecimal(attributes, "valueAddedTaxPercentage"),
-          attributes.get("currency")));
+          modelRotation, backFaceShown, modelSize, creator,
+          resizable, deformable, texturable, price, valueAddedTaxPercentage, currency);
+      piece = id != null
+          ? new HomeDoorOrWindow(id, catalogDoorOrWindow)
+          : new HomeDoorOrWindow(catalogDoorOrWindow);
     } else {
-      piece = new HomePieceOfFurniture(new CatalogPieceOfFurniture(
-          catalogId,
-          attributes.get("name"),
-          attributes.get("description"),
-          attributes.get("information"),
-          tags,
-          parseOptionalLong(attributes, "creationDate"),
-          parseOptionalFloat(attributes, "grade"),
-          parseContent(attributes.get("icon"), catalogId, false),
-          parseContent(attributes.get("planIcon"), catalogId, false),
-          parseContent(attributes.get("model"), catalogId, false),
-          parseFloat(attributes, "width"),
-          parseFloat(attributes, "depth"),
-          parseFloat(attributes, "height"),
-          elevation,
-          dropOnTopElevation,
-          !"false".equals(attributes.get("movable")),
-          attributes.get("staircaseCutOutShape"),
-          modelRotation,
-          "true".equals(attributes.get("backFaceShown")),
-          parseOptionalLong(attributes, "modelSize"),
-          attributes.get("creator"),
-          !"false".equals(attributes.get("resizable")),
-          !"false".equals(attributes.get("deformable")),
-          !"false".equals(attributes.get("texturable")),
-          !"false".equals(attributes.get("horizontallyRotatable")),
-          parseOptionalDecimal(attributes, "price"),
-          parseOptionalDecimal(attributes, "valueAddedTaxPercentage"),
-          attributes.get("currency")));
+      String staircaseCutOutShape = attributes.get("staircaseCutOutShape");
+      boolean horizontallyRotatable = !"false".equals(attributes.get("horizontallyRotatable"));
+      if ("light".equals(elementName)) {
+        CatalogLight catalogLight = new CatalogLight(catalogId, name, description, information, tags, creationDate, grade,
+            icon, planIcon, model, width, depth, height, elevation, dropOnTopElevation, movable,
+            this.lightSources.toArray(new LightSource [this.lightSources.size()]),
+            staircaseCutOutShape, modelRotation, backFaceShown, modelSize, creator, resizable, deformable, texturable,
+            horizontallyRotatable, price, valueAddedTaxPercentage, currency);
+        piece = id != null
+            ? new HomeLight(id, catalogLight)
+            : new HomeLight(catalogLight);
+      } else {
+        CatalogPieceOfFurniture catalogPiece = new CatalogPieceOfFurniture(catalogId, name, description, information, tags,
+            creationDate, grade, icon, planIcon, model, width, depth, height, elevation, dropOnTopElevation, movable,
+            staircaseCutOutShape, modelRotation, backFaceShown, modelSize, creator, resizable, deformable, texturable,
+            horizontallyRotatable, price, valueAddedTaxPercentage, currency);
+        piece = id != null
+            ? new HomePieceOfFurniture(id, catalogPiece)
+            : new HomePieceOfFurniture(catalogPiece);
+      }
     }
     return (HomePieceOfFurniture)resolveObject(piece, elementName, attributes);
   }
@@ -1236,10 +1211,13 @@ public class HomeXMLHandler extends DefaultHandler {
    */
   private HomeFurnitureGroup createFurnitureGroup(String elementName, Map<String, String> attributes,
                                                   List<HomePieceOfFurniture> furniture) throws SAXException {
-    HomeFurnitureGroup furnitureGroup = new HomeFurnitureGroup(furniture,
-        attributes.get("angle") != null ? parseFloat(attributes, "angle") : 0,
-        "true".equals(attributes.get("modelMirrored")),
-        attributes.get("name"));
+    String id = attributes.get("id");
+    float angle = attributes.get("angle") != null ? parseFloat(attributes, "angle") : 0;
+    boolean modelMirrored = "true".equals(attributes.get("modelMirrored"));
+    String name = attributes.get("name");
+    HomeFurnitureGroup furnitureGroup = id != null
+        ? new HomeFurnitureGroup(id, furniture, angle, modelMirrored, name)
+        : new HomeFurnitureGroup(furniture, angle, modelMirrored, name);
     return (HomeFurnitureGroup)resolveObject(furnitureGroup, elementName, attributes);
   }
 
@@ -1367,12 +1345,15 @@ public class HomeXMLHandler extends DefaultHandler {
    * Returns a new {@link Wall} instance initialized from the given <code>attributes</code>.
    */
   private Wall createWall(String elementName, Map<String, String> attributes) throws SAXException {
-    Wall wall = new Wall(parseFloat(attributes, "xStart"),
-        parseFloat(attributes, "yStart"),
-        parseFloat(attributes, "xEnd"),
-        parseFloat(attributes, "yEnd"),
-        parseFloat(attributes, "thickness"),
-        0);
+    String id = attributes.get("id");
+    float xStart = parseFloat(attributes, "xStart");
+    float yStart = parseFloat(attributes, "yStart");
+    float xEnd = parseFloat(attributes, "xEnd");
+    float yEnd = parseFloat(attributes, "yEnd");
+    float thickness = parseFloat(attributes, "thickness");
+    Wall wall = id != null
+        ? new Wall(id, xStart, yStart, xEnd, yEnd, thickness, 0)
+        : new Wall(xStart, yStart, xEnd, yEnd, thickness, 0);
     return (Wall)resolveObject(wall, elementName, attributes);
   }
 
@@ -1417,7 +1398,10 @@ public class HomeXMLHandler extends DefaultHandler {
    */
   private Room createRoom(String elementName, Map<String, String> attributes,
                           float[][] points) {
-    Room room = new Room(points);
+    String id = attributes.get("id");
+    Room room = id != null
+        ? new Room(id, points)
+        : new Room(points);
     return (Room)resolveObject(room, elementName, attributes);
   }
 
@@ -1478,7 +1462,10 @@ public class HomeXMLHandler extends DefaultHandler {
    */
   private Polyline createPolyline(String elementName,  Map<String, String> attributes,
                                   float[][] points) {
-    Polyline polyline = new Polyline(points);
+    String id = attributes.get("id");
+    Polyline polyline = id != null
+        ? new Polyline(id, points)
+        : new Polyline(points);
     return (Polyline)resolveObject(polyline, elementName, attributes);
   }
 
@@ -1568,11 +1555,15 @@ public class HomeXMLHandler extends DefaultHandler {
    */
   private DimensionLine createDimensionLine(String elementName,
                                             Map<String, String> attributes) throws SAXException {
-    DimensionLine dimensionLine = new DimensionLine(parseFloat(attributes, "xStart"),
-        parseFloat(attributes, "yStart"),
-        parseFloat(attributes, "xEnd"),
-        parseFloat(attributes, "yEnd"),
-        parseFloat(attributes, "offset"));
+    String id = attributes.get("id");
+    float xStart = parseFloat(attributes, "xStart");
+    float yStart = parseFloat(attributes, "yStart");
+    float xEnd = parseFloat(attributes, "xEnd");
+    float yEnd = parseFloat(attributes, "yEnd");
+    float offset = parseFloat(attributes, "offset");
+    DimensionLine dimensionLine = id != null
+        ? new DimensionLine(id, xStart, yStart, xEnd, yEnd, offset)
+        : new DimensionLine(xStart, yStart, xEnd, yEnd, offset);
     return (DimensionLine)resolveObject(dimensionLine, elementName, attributes);
   }
 
@@ -1592,9 +1583,12 @@ public class HomeXMLHandler extends DefaultHandler {
    */
   private Label createLabel(String elementName, Map<String, String> attributes,
                             String text) throws SAXException {
-    Label label = new Label(text,
-        parseFloat(attributes, "x"),
-        parseFloat(attributes, "y"));
+    String id = attributes.get("id");
+    float x = parseFloat(attributes, "x");
+    float y = parseFloat(attributes, "y");
+    Label label = id != null
+        ? new Label(id, text, x, y)
+        : new Label(text, x, y);
     return (Label)resolveObject(label, elementName, attributes);
   }
 
@@ -1796,7 +1790,7 @@ public class HomeXMLHandler extends DefaultHandler {
   private Content parseContent(String contentFile, String catalogId, boolean textureId) throws SAXException {
     if (contentFile != null) {
       try {
-        return new ResourceURLContent(new URL(contentFile), contentFile.startsWith("jar:"));
+        return new URLContent(new URL(contentFile));
       } catch (MalformedURLException ex1) {
         if (this.contentContext != null) {
           try {
