@@ -99,6 +99,7 @@ public class Wall3D extends Object3DBranch {
     setCapability(BranchGroup.ALLOW_DETACH);
     // Allow to read branch shape children
     setCapability(BranchGroup.ALLOW_CHILDREN_READ);
+    setCapability(BranchGroup.ALLOW_PICKABLE_WRITE);
 
     // Add wall bottom, baseboard, main and top shapes to branch for left and right side
     for (int i = 0; i < 8; i++) {
@@ -166,6 +167,7 @@ public class Wall3D extends Object3DBranch {
   private void updateWallGeometry(boolean waitDoorOrWindowModelsLoadingEnd) {
     updateWallSideGeometry(WALL_LEFT_SIDE, waitDoorOrWindowModelsLoadingEnd);
     updateWallSideGeometry(WALL_RIGHT_SIDE, waitDoorOrWindowModelsLoadingEnd);
+    setPickable(this.home.getEnvironment().getWallsAlpha() == 0);
   }
 
   private void updateWallSideGeometry(int wallSide,
@@ -739,7 +741,9 @@ public class Wall3D extends Object3DBranch {
     double  [] distanceSqToWallMiddle = new double [points.length];
     for (int i = 0; i < points.length; i++) {
       if (arcCircleCenter == null) {
-        distanceSqToWallMiddle [i] = Line2D.ptLineDistSq(xStart, yStart, xEnd, yEnd, bottom [i].x, bottom [i].z);
+        distanceSqToWallMiddle [i] = xStart != xEnd || yStart != yEnd
+            ? Line2D.ptLineDistSq(xStart, yStart, xEnd, yEnd, bottom [i].x, bottom [i].z)
+            : Point2D.distanceSq(xStart, yStart, bottom [i].x, bottom [i].z);
       } else {
         distanceSqToWallMiddle [i] = arcCircleRadius
             - Point2D.distance(arcCircleCenter [0], arcCircleCenter [1], bottom [i].x, bottom [i].z);
@@ -1030,8 +1034,9 @@ public class Wall3D extends Object3DBranch {
       float [] wallSecondPoint = wallSide == WALL_LEFT_SIDE
           ? wallSidePoints [wallSidePoints.length / 2 - 1]
           : wallSidePoints [wallSidePoints.length / 2];
-      float frontSideToWallDistance = (float)Line2D.ptLineDist(wallFirstPoint [0], wallFirstPoint [1],
-              wallSecondPoint [0], wallSecondPoint [1], xPieceSide, yPieceSide);
+      float frontSideToWallDistance = wallFirstPoint [0] != wallSecondPoint [0] || wallFirstPoint [1] != wallSecondPoint [1]
+          ? (float)Line2D.ptLineDist(wallFirstPoint [0], wallFirstPoint [1], wallSecondPoint [0], wallSecondPoint [1], xPieceSide, yPieceSide)
+          : (float)Point2D.distance(wallFirstPoint [0], wallFirstPoint [1], xPieceSide, yPieceSide);
       float position = (float)Line2D.relativeCCW(wallFirstPoint [0], wallFirstPoint [1],
           wallSecondPoint [0], wallSecondPoint [1], xPieceSide, yPieceSide);
       float depthTranslation = frontOrBackSide * (0.5f - position * frontSideToWallDistance / doorOrWindowDepth);
