@@ -46,7 +46,12 @@ public class Home implements Serializable, Cloneable {
    * in <code>Home</code> class or in one of the classes that it uses,
    * this number is increased.
    */
-  public static final long CURRENT_VERSION = 6000;
+  public static final long CURRENT_VERSION = 6400;
+
+  private static final String  HOME_TOP_CAMERA_ID         = "camera-homeTopCamera";
+  private static final String  HOME_OBSERVER_CAMERA_ID    = "observerCamera-homeObserverCamera";
+  private static final String  HOME_ENVIRONMENT_ID        = "environment-homeEnvironment";
+  private static final String  HOME_COMPASS_ID            = "compass-homeCompass";
 
   private static final boolean KEEP_BACKWARD_COMPATIBLITY = true;
 
@@ -295,6 +300,74 @@ public class Home implements Serializable, Cloneable {
       moveVisualProperty("com.eteks.sweethome3d.SweetHome3D.ScreenHeight");
     }
 
+    if (this.version < 6400) {
+      // Ensure environment, compass, topCamera and observerCamera have their ID set to the default IDs
+      // Create a copy of environment with the expected ID
+      HomeEnvironment environment = new HomeEnvironment(HOME_ENVIRONMENT_ID,
+          this.environment.getGroundColor(), this.environment.getGroundTexture(),
+          this.environment.getSkyColor(), this.environment.getSkyTexture(),
+          this.environment.getLightColor(), this.environment.getWallsAlpha());
+      for (String name : this.environment.getPropertyNames()) {
+        environment.setProperty(name, this.environment.getProperty(name));
+      }
+      environment.setBackgroundImageVisibleOnGround3D(this.environment.isBackgroundImageVisibleOnGround3D());
+      environment.setAllLevelsVisible(this.environment.isAllLevelsVisible());
+      environment.setObserverCameraElevationAdjusted(this.environment.isObserverCameraElevationAdjusted());
+      environment.setCeillingLightColor(this.environment.getCeillingLightColor());
+      environment.setDrawingMode(this.environment.getDrawingMode());
+      environment.setSubpartSizeUnderLight(this.environment.getSubpartSizeUnderLight());
+      environment.setPhotoWidth(this.environment.getPhotoWidth());
+      environment.setPhotoHeight(this.environment.getPhotoHeight());
+      environment.setPhotoAspectRatio(this.environment.getPhotoAspectRatio());
+      environment.setPhotoQuality(this.environment.getPhotoQuality());
+      environment.setVideoWidth(this.environment.getVideoWidth());
+      environment.setVideoAspectRatio(this.environment.getVideoAspectRatio());
+      environment.setVideoQuality(this.environment.getVideoQuality());
+      environment.setVideoSpeed(this.environment.getVideoSpeed());
+      environment.setVideoFrameRate(this.environment.getVideoFrameRate());
+      environment.setVideoCameraPath(this.environment.getVideoCameraPath());
+      this.environment = environment;
+
+      // Create a copy of compass with the expected ID
+      Compass compass = new Compass(HOME_COMPASS_ID, this.compass.getX(), this.compass.getY(), this.compass.getDiameter());
+      for (String name : this.compass.getPropertyNames()) {
+        compass.setProperty(name, this.compass.getProperty(name));
+      }
+      compass.setNorthDirection(this.compass.getNorthDirection());
+      compass.setLongitude(this.compass.getLongitude());
+      compass.setLatitude(this.compass.getLatitude());
+      compass.setTimeZone(this.compass.getTimeZone());
+      compass.setVisible(this.compass.isVisible());
+      this.compass = compass;
+
+      // Create copies of cameras with expected IDs
+      Camera topCamera = new Camera(HOME_TOP_CAMERA_ID, this.topCamera.getX(), this.topCamera.getY(), this.topCamera.getZ(),
+          this.topCamera.getYaw(), this.topCamera.getPitch(), this.topCamera.getFieldOfView());
+      for (String name : this.topCamera.getPropertyNames()) {
+        topCamera.setProperty(name, this.topCamera.getProperty(name));
+      }
+      topCamera.setLens(this.topCamera.getLens());
+      topCamera.setTime(this.topCamera.getTime());
+      if (this.camera == this.topCamera) {
+        this.camera = topCamera;
+      }
+      this.topCamera = topCamera;
+
+      ObserverCamera observerCamera = new ObserverCamera(HOME_OBSERVER_CAMERA_ID,
+          this.observerCamera.getX(), this.observerCamera.getY(), this.observerCamera.getZ(),
+          this.observerCamera.getYaw(), this.observerCamera.getPitch(), this.observerCamera.getFieldOfView());
+      for (String name : this.observerCamera.getPropertyNames()) {
+        observerCamera.setProperty(name, this.observerCamera.getProperty(name));
+      }
+      observerCamera.setFixedSize(this.observerCamera.isFixedSize());
+      observerCamera.setLens(this.observerCamera.getLens());
+      observerCamera.setTime(this.observerCamera.getTime());
+      if (this.camera == this.observerCamera) {
+        this.camera = observerCamera;
+      }
+      this.observerCamera = observerCamera;
+    }
+
     addModelListeners();
   }
 
@@ -324,19 +397,19 @@ public class Home implements Serializable, Cloneable {
           HomePieceOfFurniture.SortableProperty.VISIBLE});
     }
     // Create a default top camera that matches default point of view
-    this.topCamera = new Camera(50, 1050, 1010,
+    this.topCamera = new Camera(HOME_TOP_CAMERA_ID, 50, 1050, 1010,
         (float)Math.PI, (float)Math.PI / 4, (float)Math.PI * 63 / 180);
     // Create a default observer camera (use a 63 field of view equivalent to a 35mm lens for a 24x36 film)
-    this.observerCamera = new ObserverCamera(50, 50, 170,
+    this.observerCamera = new ObserverCamera(HOME_OBSERVER_CAMERA_ID, 50, 50, 170,
         7 * (float)Math.PI / 4, (float)Math.PI / 16, (float)Math.PI * 63 / 180);
     this.storedCameras = Collections.emptyList();
     // Initialize new fields
-    this.environment = new HomeEnvironment();
+    this.environment = new HomeEnvironment(HOME_ENVIRONMENT_ID);
     this.rooms = new ArrayList<Room>();
     this.polylines = new ArrayList<Polyline>();
     this.dimensionLines = new ArrayList<DimensionLine>();
     this.labels = new ArrayList<Label>();
-    this.compass = new Compass(-100, 50, 100);
+    this.compass = new Compass(HOME_COMPASS_ID, -100, 50, 100);
     this.levels = new ArrayList<Level>();
     // Let compass be visible only on new homes
     this.compass.setVisible(newHome);
@@ -1196,27 +1269,27 @@ public class Home implements Serializable, Cloneable {
 
   /**
    * Returns all the selectable and viewable items in this home, except the observer camera.
-   * @return a list containing viewable walls, furniture, dimension lines, labels and compass.
+   * @return a list containing viewable walls, rooms, furniture, dimension lines, polylines, labels and compass.
    * @since 5.0
    */
   public List<Selectable> getSelectableViewableItems() {
-    List<Selectable> homeItems = new ArrayList<Selectable>();
-    addViewableItems(this.walls, homeItems);
-    addViewableItems(this.rooms, homeItems);
-    addViewableItems(this.dimensionLines, homeItems);
-    addViewableItems(this.polylines, homeItems);
-    addViewableItems(this.labels, homeItems);
+    List<Selectable> items = new ArrayList<Selectable>();
+    addViewableItems(this.walls, items);
+    addViewableItems(this.rooms, items);
+    addViewableItems(this.dimensionLines, items);
+    addViewableItems(this.polylines, items);
+    addViewableItems(this.labels, items);
     for (HomePieceOfFurniture piece : getFurniture()) {
       if (piece.isVisible()
           && (piece.getLevel() == null
               || piece.getLevel().isViewable())) {
-        homeItems.add(piece);
+        items.add(piece);
       }
     }
-    if (getCompass().isVisible()) {
-      homeItems.add(getCompass());
+    if (this.compass.isVisible()) {
+      items.add(this.compass);
     }
-    return homeItems;
+    return items;
   }
 
   /**
@@ -1235,6 +1308,35 @@ public class Home implements Serializable, Cloneable {
     }
   }
 
+  /**
+   * Returns all the mutable objects handled by this home.
+   * @return a list containing environment, compass, levels, walls, rooms, furniture and their possible children,
+   * polylines, dimension lines, labels and cameras.
+   * @since 6.4
+   */
+  public List<HomeObject> getHomeObjects() {
+    List<HomeObject> homeItems = new ArrayList<HomeObject>();
+    homeItems.add(this.environment);
+    homeItems.add(this.compass);
+    homeItems.addAll(this.levels);
+    homeItems.addAll(this.walls);
+    homeItems.addAll(this.rooms);
+    homeItems.addAll(this.dimensionLines);
+    homeItems.addAll(this.polylines);
+    homeItems.addAll(this.labels);
+    for (HomePieceOfFurniture piece : getFurniture()) {
+      homeItems.add(piece);
+      if (piece instanceof HomeFurnitureGroup) {
+        homeItems.addAll(((HomeFurnitureGroup)piece).getAllFurniture());
+      }
+    }
+    homeItems.add(this.topCamera);
+    homeItems.add(this.observerCamera);
+    homeItems.addAll(this.storedCameras);
+    homeItems.addAll(this.environment.getVideoCameraPath());
+    return homeItems;
+  }
+
   /**
    * Returns <code>true</code> if this home doesn't contain any item i.e.
    * no piece of furniture, no wall, no room, no dimension line and no label.
@@ -1251,6 +1353,8 @@ public class Home implements Serializable, Cloneable {
 
   /**
    * Adds the property change <code>listener</code> in parameter to this home.
+   * Properties change will be notified with an event of {@link PropertyChangeEvent} class which property name
+   * will be equal to the value returned by {@link Property#name()} call.
    * @param property the property to follow
    * @param listener the listener to add
    */
@@ -1595,18 +1699,26 @@ public class Home implements Serializable, Cloneable {
   }
 
   /**
-   * Sets a property associated with this home.
+   * Sets a property associated with this home. Once the property is updated,
+   * listeners added to this home will receive a change event of
+   * {@link PropertyChangeEvent} class.<br>
+   * To avoid any issue with existing or future properties of Sweet Home 3D classes,
+   * do not use property names written with only upper case letters.
    * @param name   the name of the property to set
    * @param value  the new value of the property
    * @since 5.2
    */
   public void setProperty(String name, String value) {
+    String oldValue = this.properties.get(name);
     if (value == null) {
-      if (this.properties.containsKey(name)) {
+      if (oldValue != null) {
         this.properties.remove(name);
+        this.propertyChangeSupport.firePropertyChange(name, oldValue, null);
       }
     } else {
       this.properties.put(name, value);
+      // Event fired only if not null value changed
+      this.propertyChangeSupport.firePropertyChange(name, oldValue, value);
     }
   }
 
@@ -1619,6 +1731,26 @@ public class Home implements Serializable, Cloneable {
     return this.properties.keySet();
   }
 
+  /**
+   * Adds the property change <code>listener</code> in parameter to this home for a specific property name.
+   * Properties set with {@link #setProperty(String, String) setProperty} will be notified with
+   * an event of {@link PropertyChangeEvent} class which property name will be equal to the property,
+   * whereas changes on properties of {@link Property} enum will be notified with an event where
+   * the property name will be equal to the value returned by {@link Property#name()} call.
+   * @since 6.4
+   */
+  public void addPropertyChangeListener(String propertyName, PropertyChangeListener listener) {
+    this.propertyChangeSupport.addPropertyChangeListener(propertyName, listener);
+  }
+
+  /**
+   * Removes the property change <code>listener</code> in parameter from this object.
+   * @since 6.4
+   */
+  public void removePropertyChangeListener(String propertyName, PropertyChangeListener listener) {
+    this.propertyChangeSupport.removePropertyChangeListener(propertyName, listener);
+  }
+
   /**
    * Returns <code>true</code> if the home objects belonging to the base plan
    * (generally walls, rooms, dimension lines and texts) are locked.
@@ -1705,13 +1837,6 @@ public class Home implements Serializable, Cloneable {
     destination.selectedItems = new ArrayList<Selectable>(source.selectedItems.size());
     destination.furniture = cloneSelectableItems(
         source.furniture, source.selectedItems, destination.selectedItems);
-    for (int i = 0; i < source.furniture.size(); i++) {
-      HomePieceOfFurniture piece = source.furniture.get(i);
-      if (piece instanceof HomeDoorOrWindow
-          && ((HomeDoorOrWindow)piece).isBoundToWall()) {
-        ((HomeDoorOrWindow)destination.furniture.get(i)).setBoundToWall(true);
-      }
-    }
     destination.rooms = cloneSelectableItems(source.rooms, source.selectedItems, destination.selectedItems);
     destination.dimensionLines = cloneSelectableItems(
         source.dimensionLines, source.selectedItems, destination.selectedItems);
@@ -1834,17 +1959,19 @@ public class Home implements Serializable, Cloneable {
 
   /**
    * Returns a deep copy of home selectable <code>items</code>.
-   * Cloned items are at the same index as their original.
+   * Duplicated items are at the same index as their original and use different ids.
    * @param items  the items to duplicate
    */
   public static List<Selectable> duplicate(List<? extends Selectable> items) {
     List<Selectable> list = new ArrayList<Selectable>();
     // Clone first walls list with their walls at start and end point set
-    List<Wall> clonedWalls = Wall.clone(getWallsSubList(items));
+    List<Wall> duplicatedWalls = Wall.duplicate(getWallsSubList(items));
     int wallIndex = 0;
     for (Selectable item : items) {
       if (item instanceof Wall) {
-        list.add(clonedWalls.get(wallIndex++));
+        list.add(duplicatedWalls.get(wallIndex++));
+      } else if (item instanceof HomeObject) {
+        list.add((Selectable)((HomeObject)item).duplicate());
       } else {
         list.add(item.clone());
       }
