@@ -47,7 +47,17 @@ public class HomeDoorOrWindow extends HomePieceOfFurniture implements DoorOrWind
    * @param doorOrWindow the door or window from which data are copied
    */
   public HomeDoorOrWindow(DoorOrWindow doorOrWindow) {
-    super(doorOrWindow);
+    this(createId("doorOrWindow"), doorOrWindow);
+  }
+
+  /**
+   * Creates a home door or window from an existing one.
+   * @param id           the ID of the object
+   * @param doorOrWindow the door or window from which data are copied
+   * @since 6.4
+   */
+  public HomeDoorOrWindow(String id, DoorOrWindow doorOrWindow) {
+    super(id, doorOrWindow);
     this.wallThickness = doorOrWindow.getWallThickness();
     this.wallDistance = doorOrWindow.getWallDistance();
     this.wallWidth = 1;
@@ -305,12 +315,13 @@ public class HomeDoorOrWindow extends HomePieceOfFurniture implements DoorOrWind
   }
 
   /**
-   * Returns a clone of this door or window.
+   * Returns a copy of this door or window.
+   * @since 6.4
    */
   @Override
-  public HomeDoorOrWindow clone() {
-    HomeDoorOrWindow clone = (HomeDoorOrWindow)super.clone();
-    clone.boundToWall = false;
-    return clone;
+  public HomeObject duplicate() {
+    HomeDoorOrWindow copy = (HomeDoorOrWindow)super.duplicate();
+    copy.boundToWall = false;
+    return copy;
   }
 }
