@@ -19,8 +19,8 @@
  */
 package com.eteks.sweethome3d.model;
 
+import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
-import java.beans.PropertyChangeSupport;
 import java.io.IOException;
 import java.io.ObjectInputStream;
 import java.io.Serializable;
@@ -32,7 +32,7 @@ import java.util.List;
  * The environment attributes of a home.
  * @author Emmanuel Puybaret
  */
-public class HomeEnvironment implements Serializable, Cloneable {
+public class HomeEnvironment extends HomeObject implements Serializable, Cloneable {
   private static final long serialVersionUID = 1L;
 
   /**
@@ -78,15 +78,24 @@ public class HomeEnvironment implements Serializable, Cloneable {
   private float                           videoSpeed;
   private int                             videoFrameRate;
   private List<Camera>                    cameraPath;
-  private transient PropertyChangeSupport propertyChangeSupport = new PropertyChangeSupport(this);
 
   /**
    * Creates default environment.
    */
   public HomeEnvironment() {
-    this(0xA8A8A8, // Ground color
+    this(HomeObject.createId("environment"));
+  }
+
+  /**
+   * Creates default environment.
+   * @since 6.4
+   */
+  public HomeEnvironment(String id) {
+    this(id,
+         0xA8A8A8, // Ground color
          null,     // Ground texture
          0xCCE4FC, // Sky color
+         null,     // Sky texture
          0xD0D0D0, // Light color
          0);       // Walls alpha
   }
@@ -108,6 +117,19 @@ public class HomeEnvironment implements Serializable, Cloneable {
   public HomeEnvironment(int groundColor, HomeTexture groundTexture,
                          int skyColor, HomeTexture skyTexture,
                          int lightColor, float wallsAlpha) {
+    this(HomeObject.createId("environment"), groundColor, groundTexture,
+        skyColor, skyTexture, lightColor, wallsAlpha);
+  }
+
+  /**
+   * Creates home environment from parameters.
+   * @since 6.4
+   */
+  public HomeEnvironment(String id,
+                         int groundColor, HomeTexture groundTexture,
+                         int skyColor, HomeTexture skyTexture,
+                         int lightColor, float wallsAlpha) {
+    super(id);
     this.observerCameraElevationAdjusted = true;
     this.groundColor = groundColor;
     this.groundTexture = groundTexture;
@@ -132,7 +154,6 @@ public class HomeEnvironment implements Serializable, Cloneable {
    * and reads attributes from <code>in</code> stream with default reading method.
    */
   private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException {
-    this.propertyChangeSupport = new PropertyChangeSupport(this);
     this.ceilingLightColor = 0xD0D0D0;
     this.photoWidth = 400;
     this.photoHeight = 300;
@@ -161,26 +182,20 @@ public class HomeEnvironment implements Serializable, Cloneable {
     }
   }
 
-  private void writeObject(java.io.ObjectOutputStream out) throws IOException {
-    // Write aspect ratios as strings to be able to read aspect ratio later
-    // even if enum changed in later versions
-    this.photoAspectRatioName = this.photoAspectRatio.name();
-    this.videoAspectRatioName = this.videoAspectRatio.name();
-    out.defaultWriteObject();
-  }
-
   /**
    * Adds the property change <code>listener</code> in parameter to this environment.
+   * Properties change will be notified with an event of {@link PropertyChangeEvent} class which property name
+   * will be equal to the value returned by {@link Property#name()} call.
    */
   public void addPropertyChangeListener(Property property, PropertyChangeListener listener) {
-    this.propertyChangeSupport.addPropertyChangeListener(property.name(), listener);
+    addPropertyChangeListener(property.name(), listener);
   }
 
   /**
    * Removes the property change <code>listener</code> in parameter from this environment.
    */
   public void removePropertyChangeListener(Property property, PropertyChangeListener listener) {
-    this.propertyChangeSupport.removePropertyChangeListener(property.name(), listener);
+    removePropertyChangeListener(property.name(), listener);
   }
 
   /**
@@ -200,7 +215,7 @@ public class HomeEnvironment implements Serializable, Cloneable {
   public void setObserverCameraElevationAdjusted(boolean observerCameraElevationAdjusted) {
     if (this.observerCameraElevationAdjusted != observerCameraElevationAdjusted) {
       this.observerCameraElevationAdjusted = observerCameraElevationAdjusted;
-      this.propertyChangeSupport.firePropertyChange(Property.OBSERVER_CAMERA_ELEVATION_ADJUSTED.name(),
+      firePropertyChange(Property.OBSERVER_CAMERA_ELEVATION_ADJUSTED.name(),
           !observerCameraElevationAdjusted, observerCameraElevationAdjusted);
     }
   }
@@ -219,8 +234,7 @@ public class HomeEnvironment implements Serializable, Cloneable {
     if (groundColor != this.groundColor) {
       int oldGroundColor = this.groundColor;
       this.groundColor = groundColor;
-      this.propertyChangeSupport.firePropertyChange(
-          Property.GROUND_COLOR.name(), oldGroundColor, groundColor);
+      firePropertyChange(Property.GROUND_COLOR.name(), oldGroundColor, groundColor);
     }
   }
 
@@ -238,8 +252,7 @@ public class HomeEnvironment implements Serializable, Cloneable {
     if (groundTexture != this.groundTexture) {
       HomeTexture oldGroundTexture = this.groundTexture;
       this.groundTexture = groundTexture;
-      this.propertyChangeSupport.firePropertyChange(
-          Property.GROUND_TEXTURE.name(), oldGroundTexture, groundTexture);
+      firePropertyChange(Property.GROUND_TEXTURE.name(), oldGroundTexture, groundTexture);
     }
   }
 
@@ -259,7 +272,7 @@ public class HomeEnvironment implements Serializable, Cloneable {
   public void setBackgroundImageVisibleOnGround3D(boolean backgroundImageVisibleOnGround3D) {
     if (this.backgroundImageVisibleOnGround3D != backgroundImageVisibleOnGround3D) {
       this.backgroundImageVisibleOnGround3D = backgroundImageVisibleOnGround3D;
-      this.propertyChangeSupport.firePropertyChange(Property.BACKGROUND_IMAGE_VISIBLE_ON_GROUND_3D.name(),
+      firePropertyChange(Property.BACKGROUND_IMAGE_VISIBLE_ON_GROUND_3D.name(),
           !backgroundImageVisibleOnGround3D, backgroundImageVisibleOnGround3D);
     }
   }
@@ -278,8 +291,7 @@ public class HomeEnvironment implements Serializable, Cloneable {
     if (skyColor != this.skyColor) {
       int oldSkyColor = this.skyColor;
       this.skyColor = skyColor;
-      this.propertyChangeSupport.firePropertyChange(
-          Property.SKY_COLOR.name(), oldSkyColor, skyColor);
+      firePropertyChange(Property.SKY_COLOR.name(), oldSkyColor, skyColor);
     }
   }
 
@@ -297,8 +309,7 @@ public class HomeEnvironment implements Serializable, Cloneable {
     if (skyTexture != this.skyTexture) {
       HomeTexture oldSkyTexture = this.skyTexture;
       this.skyTexture = skyTexture;
-      this.propertyChangeSupport.firePropertyChange(
-          Property.SKY_TEXTURE.name(), oldSkyTexture, skyTexture);
+      firePropertyChange(Property.SKY_TEXTURE.name(), oldSkyTexture, skyTexture);
     }
   }
 
@@ -316,8 +327,7 @@ public class HomeEnvironment implements Serializable, Cloneable {
     if (lightColor != this.lightColor) {
       int oldLightColor = this.lightColor;
       this.lightColor = lightColor;
-      this.propertyChangeSupport.firePropertyChange(
-          Property.LIGHT_COLOR.name(), oldLightColor, lightColor);
+      firePropertyChange(Property.LIGHT_COLOR.name(), oldLightColor, lightColor);
     }
   }
 
@@ -335,8 +345,7 @@ public class HomeEnvironment implements Serializable, Cloneable {
     if (ceilingLightColor != this.ceilingLightColor) {
       int oldCeilingLightColor = this.ceilingLightColor;
       this.ceilingLightColor = ceilingLightColor;
-      this.propertyChangeSupport.firePropertyChange(
-          Property.CEILING_LIGHT_COLOR.name(), oldCeilingLightColor, ceilingLightColor);
+      firePropertyChange(Property.CEILING_LIGHT_COLOR.name(), oldCeilingLightColor, ceilingLightColor);
     }
   }
 
@@ -355,8 +364,7 @@ public class HomeEnvironment implements Serializable, Cloneable {
     if (wallsAlpha != this.wallsAlpha) {
       float oldWallsAlpha = this.wallsAlpha;
       this.wallsAlpha = wallsAlpha;
-      this.propertyChangeSupport.firePropertyChange(
-          Property.WALLS_ALPHA.name(), oldWallsAlpha, wallsAlpha);
+      firePropertyChange(Property.WALLS_ALPHA.name(), oldWallsAlpha, wallsAlpha);
     }
   }
 
@@ -374,8 +382,7 @@ public class HomeEnvironment implements Serializable, Cloneable {
     if (drawingMode != this.drawingMode) {
       DrawingMode oldDrawingMode = this.drawingMode;
       this.drawingMode = drawingMode;
-      this.propertyChangeSupport.firePropertyChange(
-          Property.DRAWING_MODE.name(), oldDrawingMode, drawingMode);
+      firePropertyChange(Property.DRAWING_MODE.name(), oldDrawingMode, drawingMode);
     }
   }
 
@@ -396,8 +403,7 @@ public class HomeEnvironment implements Serializable, Cloneable {
     if (subpartSizeUnderLight != this.subpartSizeUnderLight) {
       float oldSubpartWidthUnderLight = this.subpartSizeUnderLight;
       this.subpartSizeUnderLight = subpartSizeUnderLight;
-      this.propertyChangeSupport.firePropertyChange(
-          Property.SUBPART_SIZE_UNDER_LIGHT.name(), oldSubpartWidthUnderLight, subpartSizeUnderLight);
+      firePropertyChange(Property.SUBPART_SIZE_UNDER_LIGHT.name(), oldSubpartWidthUnderLight, subpartSizeUnderLight);
     }
   }
 
@@ -414,8 +420,7 @@ public class HomeEnvironment implements Serializable, Cloneable {
   public void setAllLevelsVisible(boolean allLevelsVisible) {
     if (allLevelsVisible != this.allLevelsVisible) {
       this.allLevelsVisible = allLevelsVisible;
-      this.propertyChangeSupport.firePropertyChange(
-          Property.ALL_LEVELS_VISIBLE.name(), !allLevelsVisible, allLevelsVisible);
+      firePropertyChange(Property.ALL_LEVELS_VISIBLE.name(), !allLevelsVisible, allLevelsVisible);
     }
   }
 
@@ -436,8 +441,7 @@ public class HomeEnvironment implements Serializable, Cloneable {
     if (this.photoWidth != photoWidth) {
       int oldPhotoWidth = this.photoWidth;
       this.photoWidth = photoWidth;
-      this.propertyChangeSupport.firePropertyChange(Property.PHOTO_WIDTH.name(),
-          oldPhotoWidth, photoWidth);
+      firePropertyChange(Property.PHOTO_WIDTH.name(), oldPhotoWidth, photoWidth);
     }
   }
 
@@ -458,8 +462,7 @@ public class HomeEnvironment implements Serializable, Cloneable {
     if (this.photoHeight != photoHeight) {
       int oldPhotoHeight = this.photoHeight;
       this.photoHeight = photoHeight;
-      this.propertyChangeSupport.firePropertyChange(Property.PHOTO_HEIGHT.name(),
-          oldPhotoHeight, photoHeight);
+      firePropertyChange(Property.PHOTO_HEIGHT.name(), oldPhotoHeight, photoHeight);
     }
   }
 
@@ -480,8 +483,8 @@ public class HomeEnvironment implements Serializable, Cloneable {
     if (this.photoAspectRatio != photoAspectRatio) {
       AspectRatio oldPhotoAspectRatio = this.photoAspectRatio;
       this.photoAspectRatio = photoAspectRatio;
-      this.propertyChangeSupport.firePropertyChange(Property.PHOTO_ASPECT_RATIO.name(),
-          oldPhotoAspectRatio, photoAspectRatio);
+      this.photoAspectRatioName = this.photoAspectRatio.name();
+      firePropertyChange(Property.PHOTO_ASPECT_RATIO.name(), oldPhotoAspectRatio, photoAspectRatio);
     }
   }
 
@@ -502,8 +505,7 @@ public class HomeEnvironment implements Serializable, Cloneable {
     if (this.photoQuality != photoQuality) {
       int oldPhotoQuality = this.photoQuality;
       this.photoQuality = photoQuality;
-      this.propertyChangeSupport.firePropertyChange(Property.PHOTO_QUALITY.name(),
-          oldPhotoQuality, photoQuality);
+      firePropertyChange(Property.PHOTO_QUALITY.name(), oldPhotoQuality, photoQuality);
     }
   }
 
@@ -524,8 +526,7 @@ public class HomeEnvironment implements Serializable, Cloneable {
     if (this.videoWidth != videoWidth) {
       int oldVideoWidth = this.videoWidth;
       this.videoWidth = videoWidth;
-      this.propertyChangeSupport.firePropertyChange(Property.VIDEO_WIDTH.name(),
-          oldVideoWidth, videoWidth);
+      firePropertyChange(Property.VIDEO_WIDTH.name(), oldVideoWidth, videoWidth);
     }
   }
 
@@ -557,8 +558,8 @@ public class HomeEnvironment implements Serializable, Cloneable {
       }
       AspectRatio oldVideoAspectRatio = this.videoAspectRatio;
       this.videoAspectRatio = videoAspectRatio;
-      this.propertyChangeSupport.firePropertyChange(Property.VIDEO_ASPECT_RATIO.name(),
-          oldVideoAspectRatio, videoAspectRatio);
+      this.videoAspectRatioName = this.videoAspectRatio.name();
+      firePropertyChange(Property.VIDEO_ASPECT_RATIO.name(), oldVideoAspectRatio, videoAspectRatio);
     }
   }
 
@@ -579,8 +580,7 @@ public class HomeEnvironment implements Serializable, Cloneable {
     if (this.videoQuality != videoQuality) {
       int oldVideoQuality = this.videoQuality;
       this.videoQuality = videoQuality;
-      this.propertyChangeSupport.firePropertyChange(Property.VIDEO_QUALITY.name(),
-          oldVideoQuality, videoQuality);
+      firePropertyChange(Property.VIDEO_QUALITY.name(), oldVideoQuality, videoQuality);
     }
   }
 
@@ -600,8 +600,7 @@ public class HomeEnvironment implements Serializable, Cloneable {
     if (this.videoSpeed != videoSpeed) {
       float oldVideoSpeed = this.videoSpeed;
       this.videoSpeed = videoSpeed;
-      this.propertyChangeSupport.firePropertyChange(Property.VIDEO_SPEED.name(),
-          oldVideoSpeed, videoSpeed);
+      firePropertyChange(Property.VIDEO_SPEED.name(), oldVideoSpeed, videoSpeed);
     }
   }
 
@@ -622,8 +621,7 @@ public class HomeEnvironment implements Serializable, Cloneable {
     if (this.videoFrameRate != videoFrameRate) {
       int oldVideoFrameRate = this.videoFrameRate;
       this.videoFrameRate = videoFrameRate;
-      this.propertyChangeSupport.firePropertyChange(Property.VIDEO_FRAME_RATE.name(),
-          oldVideoFrameRate, videoFrameRate);
+      firePropertyChange(Property.VIDEO_FRAME_RATE.name(), oldVideoFrameRate, videoFrameRate);
     }
   }
 
@@ -648,7 +646,7 @@ public class HomeEnvironment implements Serializable, Cloneable {
       } else {
         this.cameraPath = Collections.emptyList();
       }
-      this.propertyChangeSupport.firePropertyChange(Property.VIDEO_CAMERA_PATH.name(), oldCameraPath, cameraPath);
+      firePropertyChange(Property.VIDEO_CAMERA_PATH.name(), oldCameraPath, cameraPath);
     }
   }
 
@@ -658,16 +656,11 @@ public class HomeEnvironment implements Serializable, Cloneable {
    */
   @Override
   public HomeEnvironment clone() {
-    try {
-      HomeEnvironment clone = (HomeEnvironment)super.clone();
-      clone.cameraPath = new ArrayList<Camera>(this.cameraPath.size());
-      for (Camera camera : this.cameraPath) {
-        clone.cameraPath.add(camera.clone());
-      }
-      clone.propertyChangeSupport = new PropertyChangeSupport(clone);
-      return clone;
-    } catch (CloneNotSupportedException ex) {
-      throw new IllegalStateException("Super class isn't cloneable");
+    HomeEnvironment clone = (HomeEnvironment)super.clone();
+    clone.cameraPath = new ArrayList<Camera>(this.cameraPath.size());
+    for (Camera camera : this.cameraPath) {
+      clone.cameraPath.add(camera.clone());
     }
+    return clone;
   }
 }
\ No newline at end of file
