@@ -91,7 +91,20 @@ public class HomeFurnitureGroup extends HomePieceOfFurniture {
   public HomeFurnitureGroup(List<HomePieceOfFurniture> furniture,
                             float angle, boolean modelMirrored,
                             String name) {
-    super(furniture.get(0));
+    this(createId("furnitureGroup"), furniture, angle, modelMirrored, name);
+  }
+
+  /**
+   * Creates a group from the given <code>furniture</code> list.
+   * The level of each piece of furniture of the group will be reset to <code>null</code> and if they belong to levels
+   * with different elevations, their elevation will be updated to be relative to the elevation of the lowest level.
+   * @since 6.4
+   */
+  public HomeFurnitureGroup(String id,
+                            List<HomePieceOfFurniture> furniture,
+                            float angle, boolean modelMirrored,
+                            String name) {
+    super(id, furniture.get(0));
     this.furniture = Collections.unmodifiableList(furniture);
     this.resizable = true;
     this.deformable = true;
@@ -105,11 +118,12 @@ public class HomeFurnitureGroup extends HomePieceOfFurniture {
     }
 
     setName(name);
+    setDescription(null);
     setNameVisible(false);
     setNameXOffset(0);
     setNameYOffset(0);
+    setNameAngle(0);
     setNameStyle(null);
-    setDescription(null);
     super.setMovable(movable);
     super.setAngle(angle);
     super.setModelMirrored(modelMirrored);
@@ -295,7 +309,7 @@ public class HomeFurnitureGroup extends HomePieceOfFurniture {
   }
 
   /**
-   * Returns the furniture of this group and of all its subgroups.
+   * Returns the furniture of this group and of all its subgroups, including the possible child furniture groups.
    * @since 5.0
    */
   public List<HomePieceOfFurniture> getAllFurniture() {
@@ -873,9 +887,9 @@ public class HomeFurnitureGroup extends HomePieceOfFurniture {
     if (y != getY()) {
       float dy = y - getY();
       for (HomePieceOfFurniture piece : this.furniture) {
-        piece.addPropertyChangeListener(this.furnitureListener);
-        piece.setY(piece.getY() + dy);
         piece.removePropertyChangeListener(this.furnitureListener);
+        piece.setY(piece.getY() + dy);
+        piece.addPropertyChangeListener(this.furnitureListener);
       }
       super.setY(y);
     }
@@ -1092,6 +1106,25 @@ public class HomeFurnitureGroup extends HomePieceOfFurniture {
     return false;
   }
 
+  /**
+   * Returns a copy of this object and its children with new ids.
+   * @since 6.4
+   */
+  @Override
+  public HomeObject duplicate() {
+    HomeFurnitureGroup copy = (HomeFurnitureGroup)super.duplicate();
+    // Replace cloned furniture by duplicated furniture
+     ArrayList<HomePieceOfFurniture> duplicatedFurniture = new ArrayList<HomePieceOfFurniture>(copy.furniture.size());
+    for (HomePieceOfFurniture piece : copy.furniture) {
+      piece.removePropertyChangeListener(copy.furnitureListener);
+      HomePieceOfFurniture duplicatedPiece = (HomePieceOfFurniture)piece.duplicate();
+      duplicatedFurniture.add(duplicatedPiece);
+      duplicatedPiece.addPropertyChangeListener(copy.furnitureListener);
+    }
+    copy.furniture = Collections.unmodifiableList(duplicatedFurniture);
+    return copy;
+  }
+
   /**
    * Returns a clone of this group with cloned furniture.
    */
@@ -1101,12 +1134,7 @@ public class HomeFurnitureGroup extends HomePieceOfFurniture {
     // Deep clone furniture managed by this group
     clone.furniture = new ArrayList<HomePieceOfFurniture>(this.furniture.size());
     for (HomePieceOfFurniture piece : this.furniture) {
-      HomePieceOfFurniture pieceClone = piece.clone();
-      clone.furniture.add(pieceClone);
-      if (piece instanceof HomeDoorOrWindow
-          && ((HomeDoorOrWindow)piece).isBoundToWall()) {
-        ((HomeDoorOrWindow)pieceClone).setBoundToWall(true);
-      }
+      clone.furniture.add(piece.clone());
     }
     clone.furniture = Collections.unmodifiableList(clone.furniture);
     clone.addFurnitureListener();
