@@ -20,10 +20,6 @@
 package com.eteks.sweethome3d.model;
 
 import java.awt.geom.Rectangle2D;
-import java.beans.PropertyChangeListener;
-import java.beans.PropertyChangeSupport;
-import java.io.IOException;
-import java.io.ObjectInputStream;
 
 /**
  * A free label.
@@ -31,15 +27,15 @@ import java.io.ObjectInputStream;
  */
 public class Label extends HomeObject implements Selectable, Elevatable {
   private static final long serialVersionUID = 1L;
-  
+
   private static final double TWICE_PI = 2 * Math.PI;
 
   /**
-   * The properties of a label that may change. <code>PropertyChangeListener</code>s added 
+   * The properties of a label that may change. <code>PropertyChangeListener</code>s added
    * to a label will be notified under a property name equal to the string value of one these properties.
    */
   public enum Property {TEXT, X, Y, ELEVATION, STYLE, COLOR, OUTLINE_COLOR, ANGLE, PITCH, LEVEL};
-  
+
   private String              text;
   private float               x;
   private float               y;
@@ -50,37 +46,24 @@ public class Label extends HomeObject implements Selectable, Elevatable {
   private Float               pitch;
   private float               elevation;
   private Level               level;
-  
-  private transient PropertyChangeSupport propertyChangeSupport = new PropertyChangeSupport(this);
 
+  /**
+   * Creates a label with the given <code>text</code>.
+   */
   public Label(String text, float x, float y) {
+    this(createId("label"), text, x, y);
+  }
+
+  /**
+   * Creates a label with the given <code>text</code>.
+   * @since 6.4
+   */
+  public Label(String id, String text, float x, float y) {
+    super(id);
     this.text = text;
     this.x = x;
     this.y = y;
   }
-  
-  /**
-   * Initializes transient fields to their default values 
-   * and reads label from <code>in</code> stream with default reading method.
-   */
-  private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException {
-    this.propertyChangeSupport = new PropertyChangeSupport(this);
-    in.defaultReadObject();
-  }
-
-  /**
-   * Adds the property change <code>listener</code> in parameter to this label.
-   */
-  public void addPropertyChangeListener(PropertyChangeListener listener) {
-    this.propertyChangeSupport.addPropertyChangeListener(listener);
-  }
-
-  /**
-   * Removes the property change <code>listener</code> in parameter from this label.
-   */
-  public void removePropertyChangeListener(PropertyChangeListener listener) {
-    this.propertyChangeSupport.removePropertyChangeListener(listener);
-  }
 
   /**
    * Returns the text of this label.
@@ -90,7 +73,7 @@ public class Label extends HomeObject implements Selectable, Elevatable {
   }
 
   /**
-   * Sets the text of this label. Once this label is updated, 
+   * Sets the text of this label. Once this label is updated,
    * listeners added to this label will receive a change notification.
    */
   public void setText(String text) {
@@ -98,10 +81,10 @@ public class Label extends HomeObject implements Selectable, Elevatable {
         && (text == null || !text.equals(this.text))) {
       String oldText = this.text;
       this.text = text;
-      this.propertyChangeSupport.firePropertyChange(Property.TEXT.name(), oldText, text);
+      firePropertyChange(Property.TEXT.name(), oldText, text);
     }
   }
-   
+
   /**
    * Returns the abscissa of the text of this label.
    */
@@ -110,17 +93,17 @@ public class Label extends HomeObject implements Selectable, Elevatable {
   }
 
   /**
-   * Sets the abscissa of the text of this label. Once this label is updated, 
+   * Sets the abscissa of the text of this label. Once this label is updated,
    * listeners added to this label will receive a change notification.
    */
   public void setX(float x) {
     if (x != this.x) {
       float oldX = this.x;
       this.x = x;
-      this.propertyChangeSupport.firePropertyChange(Property.X.name(), oldX, x);
+      firePropertyChange(Property.X.name(), oldX, x);
     }
   }
-  
+
   /**
    * Returns the ordinate of the text of this label.
    */
@@ -129,19 +112,19 @@ public class Label extends HomeObject implements Selectable, Elevatable {
   }
 
   /**
-   * Sets the ordinate of the text of this label. Once this label is updated, 
+   * Sets the ordinate of the text of this label. Once this label is updated,
    * listeners added to this label will receive a change notification.
    */
   public void setY(float y) {
     if (y != this.y) {
       float oldY = this.y;
       this.y = y;
-      this.propertyChangeSupport.firePropertyChange(Property.Y.name(), oldY, y);
+      firePropertyChange(Property.Y.name(), oldY, y);
     }
   }
 
   /**
-   * Returns the elevation of this label 
+   * Returns the elevation of this label
    * from the ground according to the elevation of its level.
    * @since 5.0
    */
@@ -155,23 +138,23 @@ public class Label extends HomeObject implements Selectable, Elevatable {
 
   /**
    * Returns the elevation of this label on its level.
-   * @see #getPitch() 
-   * @since 5.0 
+   * @see #getPitch()
+   * @since 5.0
    */
   public float getElevation() {
     return this.elevation;
   }
 
   /**
-   * Sets the elevation of this label on its level. Once this label is updated, 
+   * Sets the elevation of this label on its level. Once this label is updated,
    * listeners added to this label will receive a change notification.
-   * @since 5.0 
+   * @since 5.0
    */
   public void setElevation(float elevation) {
     if (elevation != this.elevation) {
       float oldElevation = this.elevation;
       this.elevation = elevation;
-      this.propertyChangeSupport.firePropertyChange(Property.ELEVATION.name(), oldElevation, elevation);
+      firePropertyChange(Property.ELEVATION.name(), oldElevation, elevation);
     }
   }
 
@@ -179,7 +162,7 @@ public class Label extends HomeObject implements Selectable, Elevatable {
    * Returns the style used to display the text of this label.
    */
   public TextStyle getStyle() {
-    return this.style;  
+    return this.style;
   }
 
   /**
@@ -190,7 +173,7 @@ public class Label extends HomeObject implements Selectable, Elevatable {
     if (style != this.style) {
       TextStyle oldStyle = this.style;
       this.style = style;
-      this.propertyChangeSupport.firePropertyChange(Property.STYLE.name(), oldStyle, style);
+      firePropertyChange(Property.STYLE.name(), oldStyle, style);
     }
   }
 
@@ -199,7 +182,7 @@ public class Label extends HomeObject implements Selectable, Elevatable {
    * @since 5.0
    */
   public Integer getColor() {
-    return this.color;  
+    return this.color;
   }
 
   /**
@@ -211,7 +194,7 @@ public class Label extends HomeObject implements Selectable, Elevatable {
     if (color != this.color) {
       Integer oldColor = this.color;
       this.color = color;
-      this.propertyChangeSupport.firePropertyChange(Property.COLOR.name(), oldColor, color);
+      firePropertyChange(Property.COLOR.name(), oldColor, color);
     }
   }
 
@@ -220,7 +203,7 @@ public class Label extends HomeObject implements Selectable, Elevatable {
    * @since 5.3
    */
   public Integer getOutlineColor() {
-    return this.outlineColor;  
+    return this.outlineColor;
   }
 
   /**
@@ -232,22 +215,22 @@ public class Label extends HomeObject implements Selectable, Elevatable {
     if (outlineColor != this.outlineColor) {
       Integer oldOutlineColor = this.outlineColor;
       this.outlineColor = outlineColor;
-      this.propertyChangeSupport.firePropertyChange(Property.OUTLINE_COLOR.name(), oldOutlineColor, outlineColor);
+      firePropertyChange(Property.OUTLINE_COLOR.name(), oldOutlineColor, outlineColor);
     }
   }
 
   /**
    * Returns the angle in radians around vertical axis used to display this label.
-   * @since 3.6 
+   * @since 3.6
    */
   public float getAngle() {
     return this.angle;
   }
 
   /**
-   * Sets the angle in radians around vertical axis used to display this label. Once this label is updated, 
+   * Sets the angle in radians around vertical axis used to display this label. Once this label is updated,
    * listeners added to this label will receive a change notification.
-   * @since 3.6 
+   * @since 3.6
    */
   public void setAngle(float angle) {
     // Ensure angle is always positive and between 0 and 2 PI
@@ -255,25 +238,25 @@ public class Label extends HomeObject implements Selectable, Elevatable {
     if (angle != this.angle) {
       float oldAngle = this.angle;
       this.angle = angle;
-      this.propertyChangeSupport.firePropertyChange(Property.ANGLE.name(), oldAngle, angle);
+      firePropertyChange(Property.ANGLE.name(), oldAngle, angle);
     }
   }
-  
+
   /**
    * Returns the pitch angle in radians used to rotate this label around horizontal axis in 3D.
    * @return an angle in radians or <code>null</code> if the label shouldn't be displayed in 3D.
-   *         A pitch angle equal to 0 should make this label fully visible when seen from top. 
-   * @since 5.0 
+   *         A pitch angle equal to 0 should make this label fully visible when seen from top.
+   * @since 5.0
    */
   public Float getPitch() {
     return this.pitch;
   }
 
   /**
-   * Sets the angle in radians used to rotate this label around horizontal axis in 3D. Once this label is updated, 
+   * Sets the angle in radians used to rotate this label around horizontal axis in 3D. Once this label is updated,
    * listeners added to this label will receive a change notification.
-   * Pitch axis is horizontal transverse axis. 
-   * @since 5.0 
+   * Pitch axis is horizontal transverse axis.
+   * @since 5.0
    */
   public void setPitch(Float pitch) {
     if (pitch != null) {
@@ -284,12 +267,12 @@ public class Label extends HomeObject implements Selectable, Elevatable {
         && (pitch == null || !pitch.equals(this.pitch))) {
       Float oldPitch = this.pitch;
       this.pitch = pitch;
-      this.propertyChangeSupport.firePropertyChange(Property.PITCH.name(), oldPitch, pitch);
+      firePropertyChange(Property.PITCH.name(), oldPitch, pitch);
     }
   }
-  
+
   /**
-   * Returns the level which this label belongs to. 
+   * Returns the level which this label belongs to.
    * @since 3.4
    */
   public Level getLevel() {
@@ -297,7 +280,7 @@ public class Label extends HomeObject implements Selectable, Elevatable {
   }
 
   /**
-   * Sets the level of this label. Once this label is updated, 
+   * Sets the level of this label. Once this label is updated,
    * listeners added to this label will receive a change notification.
    * @since 3.4
    */
@@ -305,12 +288,12 @@ public class Label extends HomeObject implements Selectable, Elevatable {
     if (level != this.level) {
       Level oldLevel = this.level;
       this.level = level;
-      this.propertyChangeSupport.firePropertyChange(Property.LEVEL.name(), oldLevel, level);
+      firePropertyChange(Property.LEVEL.name(), oldLevel, level);
     }
   }
 
   /**
-   * Returns <code>true</code> if this label is at the given <code>level</code> 
+   * Returns <code>true</code> if this label is at the given <code>level</code>
    * or at a level with the same elevation and a smaller elevation index.
    * @since 3.4
    */
@@ -320,7 +303,7 @@ public class Label extends HomeObject implements Selectable, Elevatable {
            && this.level.getElevation() == level.getElevation()
            && this.level.getElevationIndex() < level.getElevationIndex();
   }
-  
+
   /**
    * Returns the point of this label.
    * @return an array of the (x,y) coordinates of this label.
@@ -328,19 +311,19 @@ public class Label extends HomeObject implements Selectable, Elevatable {
   public float [][] getPoints() {
     return new float [][] {{this.x, this.y}};
   }
-  
+
   /**
    * Returns <code>true</code> if the point of this label is contained
    * in the horizontal rectangle which opposite corners are at points
    * (<code>x0</code>, <code>y0</code>) and (<code>x1</code>, <code>y1</code>).
    */
-  public boolean intersectsRectangle(float x0, float y0, 
+  public boolean intersectsRectangle(float x0, float y0,
                                      float x1, float y1) {
     Rectangle2D rectangle = new Rectangle2D.Float(x0, y0, 0, 0);
     rectangle.add(x1, y1);
     return rectangle.contains(this.x, this.y);
   }
-  
+
   /**
    * Returns <code>true</code> if this text is at the point at (<code>x</code>, <code>y</code>)
    * with a given <code>margin</code>.
@@ -348,7 +331,7 @@ public class Label extends HomeObject implements Selectable, Elevatable {
   public boolean containsPoint(float x, float y, float margin) {
     return Math.abs(x - this.x) <= margin && Math.abs(y - this.y) <= margin;
   }
-  
+
   /**
    * Moves this label of (<code>dx</code>, <code>dy</code>) units.
    */
@@ -356,14 +339,13 @@ public class Label extends HomeObject implements Selectable, Elevatable {
     setX(getX() + dx);
     setY(getY() + dy);
   }
-  
+
   /**
    * Returns a clone of this label.
    */
   @Override
   public Label clone() {
     Label clone = (Label)super.clone();
-    clone.propertyChangeSupport = new PropertyChangeSupport(clone);
     clone.level = null;
     return clone;
   }
