@@ -27,17 +27,26 @@ import java.io.File;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Iterator;
 import java.util.List;
 
 import javax.swing.JComponent;
+import javax.swing.JTable;
+import javax.swing.JViewport;
+import javax.swing.SwingUtilities;
+import javax.swing.table.TableModel;
 
 import com.eteks.sweethome3d.model.Home;
+import com.eteks.sweethome3d.model.HomeFurnitureGroup;
 import com.eteks.sweethome3d.model.HomePieceOfFurniture;
 import com.eteks.sweethome3d.model.Level;
 import com.eteks.sweethome3d.model.Selectable;
+import com.eteks.sweethome3d.tools.OperatingSystem;
 import com.eteks.sweethome3d.viewcontroller.ContentManager;
+import com.eteks.sweethome3d.viewcontroller.FurnitureView;
 import com.eteks.sweethome3d.viewcontroller.HomeController;
 import com.eteks.sweethome3d.viewcontroller.TransferableView;
+import com.eteks.sweethome3d.viewcontroller.View;
 
 /**
  * Home furniture transfer handler.
@@ -47,20 +56,21 @@ public class FurnitureTransferHandler extends LocatedTransferHandler {
   private final Home                 home;
   private final ContentManager       contentManager;
   private final HomeController       homeController;
+  private JComponent                 transferableSource;
   private List<HomePieceOfFurniture> copiedFurniture;
   private Object                     copiedCSV;
 
   /**
    * Creates a handler able to transfer home furniture.
    */
-  public FurnitureTransferHandler(Home home, 
+  public FurnitureTransferHandler(Home home,
                                   ContentManager contentManager,
                                   HomeController homeController) {
-    this.home = home;  
+    this.home = home;
     this.contentManager = contentManager;
     this.homeController = homeController;
   }
-  
+
   /**
    * Returns <code>COPY_OR_MOVE</code>.
    */
@@ -68,13 +78,14 @@ public class FurnitureTransferHandler extends LocatedTransferHandler {
   public int getSourceActions(JComponent source) {
     return COPY_OR_MOVE;
   }
-  
+
   /**
    * Returns a {@link HomeTransferableList transferable object}
-   * that contains a copy of the selected furniture in home. 
+   * that contains a copy of the selected furniture in home.
    */
   @Override
   protected Transferable createTransferable(JComponent source) {
+    this.transferableSource = source;
     this.copiedFurniture = Home.getFurnitureSubList(this.home.getSelectedItems());
     final Transferable transferable = new HomeTransferableList(this.copiedFurniture);
     if (source instanceof TransferableView) {
@@ -90,28 +101,28 @@ public class FurnitureTransferHandler extends LocatedTransferHandler {
               }
             }
           }, TransferableView.DataType.FURNITURE_LIST);
-      // Create a transferable that contains copied furniture and its CSV description 
+      // Create a transferable that contains copied furniture and its CSV description
       return new Transferable () {
-        public Object getTransferData(DataFlavor flavor) throws UnsupportedFlavorException, IOException {
-          if (DataFlavor.stringFlavor.equals(flavor)) {
-            return copiedCSV;
-          } else {
-            return transferable.getTransferData(flavor);
+          public Object getTransferData(DataFlavor flavor) throws UnsupportedFlavorException, IOException {
+            if (DataFlavor.stringFlavor.equals(flavor)) {
+              return copiedCSV;
+            } else {
+              return transferable.getTransferData(flavor);
+            }
           }
-        }
 
-        public DataFlavor [] getTransferDataFlavors() {
-          ArrayList<DataFlavor> dataFlavors = 
-              new ArrayList<DataFlavor>(Arrays.asList(transferable.getTransferDataFlavors()));
-          dataFlavors.add(DataFlavor.stringFlavor);
-          return dataFlavors.toArray(new DataFlavor [dataFlavors.size()]);
-        }
+          public DataFlavor [] getTransferDataFlavors() {
+            ArrayList<DataFlavor> dataFlavors =
+                new ArrayList<DataFlavor>(Arrays.asList(transferable.getTransferDataFlavors()));
+            dataFlavors.add(DataFlavor.stringFlavor);
+            return dataFlavors.toArray(new DataFlavor [dataFlavors.size()]);
+          }
 
-        public boolean isDataFlavorSupported(DataFlavor flavor) {
-          return transferable.isDataFlavorSupported(flavor)
-            || DataFlavor.stringFlavor.equals(flavor);
-        }
-      };
+          public boolean isDataFlavorSupported(DataFlavor flavor) {
+            return transferable.isDataFlavorSupported(flavor)
+              || DataFlavor.stringFlavor.equals(flavor);
+          }
+        };
     } else {
       return transferable;
     }
@@ -122,16 +133,17 @@ public class FurnitureTransferHandler extends LocatedTransferHandler {
    */
   @Override
   protected void exportDone(JComponent source, Transferable data, int action) {
-    if (action == MOVE) {
-      this.homeController.cut(copiedFurniture);      
+    if (action == MOVE && this.copiedFurniture != null) {
+      this.homeController.cut(this.copiedFurniture);
     }
+    this.transferableSource =  null;
     this.copiedFurniture = null;
     this.copiedCSV = null;
     this.homeController.enablePasteAction();
   }
 
   /**
-   * Returns <code>true</code> if flavors contains 
+   * Returns <code>true</code> if flavors contains
    * {@link HomeTransferableList#HOME_FLAVOR HOME_FLAVOR} flavor
    * or <code>DataFlavor.javaFileListFlavor</code> flavor.
    */
@@ -153,13 +165,24 @@ public class FurnitureTransferHandler extends LocatedTransferHandler {
       try {
         List<DataFlavor> flavorList = Arrays.asList(transferable.getTransferDataFlavors());
         if (flavorList.contains(HomeTransferableList.HOME_FLAVOR)) {
-          List<Selectable> items = (List<Selectable>)transferable.
-              getTransferData(HomeTransferableList.HOME_FLAVOR);
+          List<Selectable> items = (List<Selectable>)transferable.getTransferData(HomeTransferableList.HOME_FLAVOR);
           List<HomePieceOfFurniture> furniture = Home.getFurnitureSubList(items);
           if (isDrop()) {
-            this.homeController.drop(furniture, 0, 0);
+            HomePieceOfFurniture beforePiece = getDropPieceOfFurniture(destination);
+            View furnitureView = this.homeController.getFurnitureController().getView();
+            if ((destination == this.transferableSource
+                   || destination instanceof JViewport
+                       && ((JViewport)destination).getView() == this.transferableSource)
+                && furnitureView != null) {
+              this.homeController.getFurnitureController().moveSelectedFurnitureBefore(beforePiece);
+            } else {
+              this.homeController.drop(furniture,
+                  furnitureView != null && SwingUtilities.isDescendingFrom(destination, (JComponent)furnitureView) ? furnitureView : null,
+                  beforePiece);
+            }
+            this.copiedFurniture = null;
           } else {
-            this.homeController.paste(furniture);          
+            this.homeController.paste(furniture);
           }
           return true;
         } else {
@@ -167,7 +190,7 @@ public class FurnitureTransferHandler extends LocatedTransferHandler {
           final List<String> importableModels = getModelContents(files, this.contentManager);
           EventQueue.invokeLater(new Runnable() {
               public void run() {
-                homeController.dropFiles(importableModels, 0, 0);          
+                homeController.dropFiles(importableModels, 0, 0);
               }
             });
           return !importableModels.isEmpty();
@@ -181,4 +204,71 @@ public class FurnitureTransferHandler extends LocatedTransferHandler {
       return false;
     }
   }
+
+  /**
+   * Returns the piece of furniture upon which the cursor was dropped.
+   */
+  private HomePieceOfFurniture getDropPieceOfFurniture(JComponent destination) {
+    if (OperatingSystem.isJavaVersionGreaterOrEqual("1.6")
+        && destination instanceof FurnitureView) {
+      try {
+        // Call Java 6 getDropLocation().getRow() by reflection
+        Object dropLocation = destination.getClass().getMethod("getDropLocation").invoke(destination);
+        if ((Boolean)dropLocation.getClass().getMethod("isInsertRow").invoke(dropLocation)) {
+          int row = (Integer)dropLocation.getClass().getMethod("getRow").invoke(dropLocation);
+          TableModel tableModel = ((JTable)destination).getModel();
+          if (row != -1
+              && row < tableModel.getRowCount()) {
+            HomePieceOfFurniture piece = (HomePieceOfFurniture)tableModel.getValueAt(row, 0);
+            if (this.copiedFurniture != null) {
+              // Search first piece which is not copied
+              while (this.copiedFurniture.contains(piece)
+                     || isPieceOfFurnitureChild(piece, this.copiedFurniture)) {
+                if (++row < tableModel.getRowCount()) {
+                  piece = (HomePieceOfFurniture)tableModel.getValueAt(row, 0);
+                } else {
+                  piece = null;
+                  break;
+                }
+              }
+              if (piece instanceof HomeFurnitureGroup) {
+                // Don't handle complicated cases where the group would be emptied by a move
+                HomeFurnitureGroup group = (HomeFurnitureGroup)piece;
+                if (this.copiedFurniture.containsAll(group.getFurniture())) {
+                  piece = null;
+                }
+                List<HomePieceOfFurniture> groupFurniture = new ArrayList<HomePieceOfFurniture>(group.getAllFurniture());
+                for (Iterator<HomePieceOfFurniture> it = groupFurniture.iterator(); it.hasNext();) {
+                  if (it.next() instanceof HomeFurnitureGroup) {
+                    it.remove();
+                  }
+                }
+                if (this.copiedFurniture.containsAll(groupFurniture)) {
+                  piece = null;
+                }
+              }
+            }
+            return piece;
+          }
+        }
+      } catch (Exception ex) {
+        // Shouldn't happen
+        ex.printStackTrace();
+      }
+    }
+    return null;
+  }
+
+  /**
+   * Returns <code>true</code> if the given <code>piece</code> is a child of furniture groups among <code>furniture</code>.
+   */
+  private boolean isPieceOfFurnitureChild(HomePieceOfFurniture piece, List<HomePieceOfFurniture> furniture) {
+    for (HomePieceOfFurniture item : furniture) {
+      if (item instanceof HomeFurnitureGroup
+          && ((HomeFurnitureGroup)item).getAllFurniture().contains(piece)) {
+        return true;
+      }
+    }
+    return false;
+  }
 }
