@@ -103,11 +103,11 @@ public class RoomPanel extends JPanel implements DialogView {
   /**
    * Creates and initializes components and spinners model.
    */
-  private void createComponents(UserPreferences preferences, 
+  private void createComponents(UserPreferences preferences,
                                 final RoomController controller) {
     if (controller.isPropertyEditable(RoomController.Property.NAME)) {
       // Create name label and its text field bound to NAME controller property
-      this.nameLabel = new JLabel(SwingTools.getLocalizedLabelText(preferences, 
+      this.nameLabel = new JLabel(SwingTools.getLocalizedLabelText(preferences,
           RoomPanel.class, "nameLabel.text"));
       this.nameTextField = new AutoCompleteTextField(controller.getName(), 10, preferences.getAutoCompletionStrings("RoomName"));
       if (!OperatingSystem.isMacOSXLeopardOrSuperior()) {
@@ -122,7 +122,7 @@ public class RoomPanel extends JPanel implements DialogView {
       this.nameTextField.getDocument().addDocumentListener(new DocumentListener() {
           public void changedUpdate(DocumentEvent ev) {
             controller.removePropertyChangeListener(RoomController.Property.NAME, nameChangeListener);
-            String name = nameTextField.getText(); 
+            String name = nameTextField.getText();
             if (name == null || name.trim().length() == 0) {
               controller.setName("");
             } else {
@@ -130,20 +130,20 @@ public class RoomPanel extends JPanel implements DialogView {
             }
             controller.addPropertyChangeListener(RoomController.Property.NAME, nameChangeListener);
           }
-    
+
           public void insertUpdate(DocumentEvent ev) {
             changedUpdate(ev);
           }
-    
+
           public void removeUpdate(DocumentEvent ev) {
             changedUpdate(ev);
           }
         });
     }
-    
+
     if (controller.isPropertyEditable(RoomController.Property.AREA_VISIBLE)) {
       // Create area visible check box bound to AREA_VISIBLE controller property
-      this.areaVisibleCheckBox = new NullableCheckBox(SwingTools.getLocalizedLabelText(preferences, 
+      this.areaVisibleCheckBox = new NullableCheckBox(SwingTools.getLocalizedLabelText(preferences,
           RoomPanel.class, "areaVisibleCheckBox.text"));
       this.areaVisibleCheckBox.setNullable(controller.getAreaVisible() == null);
       this.areaVisibleCheckBox.setValue(controller.getAreaVisible());
@@ -162,10 +162,10 @@ public class RoomPanel extends JPanel implements DialogView {
           }
         });
     }
-    
+
     if (controller.isPropertyEditable(RoomController.Property.FLOOR_VISIBLE)) {
       // Create floor visible check box bound to FLOOR_VISIBLE controller property
-      this.floorVisibleCheckBox = new NullableCheckBox(SwingTools.getLocalizedLabelText(preferences, 
+      this.floorVisibleCheckBox = new NullableCheckBox(SwingTools.getLocalizedLabelText(preferences,
           RoomPanel.class, "floorVisibleCheckBox.text"));
       this.floorVisibleCheckBox.setNullable(controller.getFloorVisible() == null);
       this.floorVisibleCheckBox.setValue(controller.getFloorVisible());
@@ -184,10 +184,10 @@ public class RoomPanel extends JPanel implements DialogView {
           }
         });
     }
-    
+
     if (controller.isPropertyEditable(RoomController.Property.FLOOR_PAINT)) {
       // Floor color and texture buttons bound to floor controller properties
-      this.floorColorRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences, 
+      this.floorColorRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences,
           RoomPanel.class, "floorColorRadioButton.text"));
       this.floorColorRadioButton.addChangeListener(new ChangeListener() {
           public void stateChanged(ChangeEvent ev) {
@@ -196,32 +196,32 @@ public class RoomPanel extends JPanel implements DialogView {
             }
           }
         });
-      controller.addPropertyChangeListener(RoomController.Property.FLOOR_PAINT, 
+      controller.addPropertyChangeListener(RoomController.Property.FLOOR_PAINT,
           new PropertyChangeListener() {
             public void propertyChange(PropertyChangeEvent ev) {
               updateFloorColorRadioButtons(controller);
             }
           });
-      
+
       this.floorColorButton = new ColorButton(preferences);
       this.floorColorButton.setColorDialogTitle(preferences.getLocalizedString(
           RoomPanel.class, "floorColorDialog.title"));
       this.floorColorButton.setColor(controller.getFloorColor());
-      this.floorColorButton.addPropertyChangeListener(ColorButton.COLOR_PROPERTY, 
+      this.floorColorButton.addPropertyChangeListener(ColorButton.COLOR_PROPERTY,
           new PropertyChangeListener() {
             public void propertyChange(PropertyChangeEvent ev) {
               controller.setFloorColor(floorColorButton.getColor());
               controller.setFloorPaint(RoomController.RoomPaint.COLORED);
             }
           });
-      controller.addPropertyChangeListener(RoomController.Property.FLOOR_COLOR, 
+      controller.addPropertyChangeListener(RoomController.Property.FLOOR_COLOR,
           new PropertyChangeListener() {
             public void propertyChange(PropertyChangeEvent ev) {
               floorColorButton.setColor(controller.getFloorColor());
             }
           });
-    
-      this.floorTextureRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences, 
+
+      this.floorTextureRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences,
           RoomPanel.class, "floorTextureRadioButton.text"));
       this.floorTextureRadioButton.addChangeListener(new ChangeListener() {
           public void stateChanged(ChangeEvent ev) {
@@ -230,18 +230,18 @@ public class RoomPanel extends JPanel implements DialogView {
             }
           }
         });
-      
+
       this.floorTextureComponent = (JComponent)controller.getFloorTextureController().getView();
-      
+
       ButtonGroup floorButtonColorGroup = new ButtonGroup();
       floorButtonColorGroup.add(this.floorColorRadioButton);
       floorButtonColorGroup.add(this.floorTextureRadioButton);
       updateFloorColorRadioButtons(controller);
     }
-      
+
     if (controller.isPropertyEditable(RoomController.Property.FLOOR_SHININESS)) {
       // Floor shininess radio buttons bound to FLOOR_SHININESS controller property
-      this.floorMattRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences, 
+      this.floorMattRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences,
           RoomPanel.class, "floorMattRadioButton.text"));
       this.floorMattRadioButton.addChangeListener(new ChangeListener() {
           public void stateChanged(ChangeEvent ev) {
@@ -255,10 +255,10 @@ public class RoomPanel extends JPanel implements DialogView {
             updateFloorShininessRadioButtons(controller);
           }
         };
-      controller.addPropertyChangeListener(RoomController.Property.FLOOR_SHININESS, 
+      controller.addPropertyChangeListener(RoomController.Property.FLOOR_SHININESS,
           floorShininessListener);
-  
-      this.floorShinyRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences, 
+
+      this.floorShinyRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences,
           RoomPanel.class, "floorShinyRadioButton.text"));
       this.floorShinyRadioButton.addChangeListener(new ChangeListener() {
           public void stateChanged(ChangeEvent ev) {
@@ -267,18 +267,18 @@ public class RoomPanel extends JPanel implements DialogView {
             }
           }
         });
-      controller.addPropertyChangeListener(RoomController.Property.FLOOR_SHININESS, 
+      controller.addPropertyChangeListener(RoomController.Property.FLOOR_SHININESS,
           floorShininessListener);
-      
+
       ButtonGroup floorShininessButtonGroup = new ButtonGroup();
       floorShininessButtonGroup.add(this.floorMattRadioButton);
       floorShininessButtonGroup.add(this.floorShinyRadioButton);
       updateFloorShininessRadioButtons(controller);
     }
-    
+
     if (controller.isPropertyEditable(RoomController.Property.CEILING_VISIBLE)) {
       // Create ceiling visible check box bound to CEILING_VISIBLE controller property
-      this.ceilingVisibleCheckBox = new NullableCheckBox(SwingTools.getLocalizedLabelText(preferences, 
+      this.ceilingVisibleCheckBox = new NullableCheckBox(SwingTools.getLocalizedLabelText(preferences,
           RoomPanel.class, "ceilingVisibleCheckBox.text"));
       this.ceilingVisibleCheckBox.setNullable(controller.getCeilingVisible() == null);
       this.ceilingVisibleCheckBox.setValue(controller.getCeilingVisible());
@@ -297,10 +297,10 @@ public class RoomPanel extends JPanel implements DialogView {
           }
         });
     }
-  
+
     if (controller.isPropertyEditable(RoomController.Property.CEILING_PAINT)) {
       // Ceiling color and texture buttons bound to ceiling controller properties
-      this.ceilingColorRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences, 
+      this.ceilingColorRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences,
           RoomPanel.class, "ceilingColorRadioButton.text"));
       this.ceilingColorRadioButton.addChangeListener(new ChangeListener() {
           public void stateChanged(ChangeEvent e) {
@@ -309,32 +309,32 @@ public class RoomPanel extends JPanel implements DialogView {
             }
           }
         });
-      controller.addPropertyChangeListener(RoomController.Property.CEILING_PAINT, 
+      controller.addPropertyChangeListener(RoomController.Property.CEILING_PAINT,
           new PropertyChangeListener() {
             public void propertyChange(PropertyChangeEvent ev) {
               updateCeilingColorRadioButtons(controller);
             }
           });
-    
+
       this.ceilingColorButton = new ColorButton(preferences);
       this.ceilingColorButton.setColor(controller.getCeilingColor());
       this.ceilingColorButton.setColorDialogTitle(preferences.getLocalizedString(
           RoomPanel.class, "ceilingColorDialog.title"));
-      this.ceilingColorButton.addPropertyChangeListener(ColorButton.COLOR_PROPERTY, 
+      this.ceilingColorButton.addPropertyChangeListener(ColorButton.COLOR_PROPERTY,
           new PropertyChangeListener() {
             public void propertyChange(PropertyChangeEvent ev) {
               controller.setCeilingColor(ceilingColorButton.getColor());
               controller.setCeilingPaint(RoomController.RoomPaint.COLORED);
             }
           });
-      controller.addPropertyChangeListener(RoomController.Property.CEILING_COLOR, 
+      controller.addPropertyChangeListener(RoomController.Property.CEILING_COLOR,
           new PropertyChangeListener() {
             public void propertyChange(PropertyChangeEvent ev) {
               ceilingColorButton.setColor(controller.getCeilingColor());
             }
           });
-      
-      this.ceilingTextureRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences, 
+
+      this.ceilingTextureRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences,
           RoomPanel.class, "ceilingTextureRadioButton.text"));
       this.ceilingTextureRadioButton.addChangeListener(new ChangeListener() {
           public void stateChanged(ChangeEvent e) {
@@ -343,18 +343,18 @@ public class RoomPanel extends JPanel implements DialogView {
             }
           }
         });
-    
+
       this.ceilingTextureComponent = (JComponent)controller.getCeilingTextureController().getView();
-  
+
       ButtonGroup ceilingColorButtonGroup = new ButtonGroup();
       ceilingColorButtonGroup.add(this.ceilingColorRadioButton);
       ceilingColorButtonGroup.add(this.ceilingTextureRadioButton);
       updateCeilingColorRadioButtons(controller);
     }
-    
+
     if (controller.isPropertyEditable(RoomController.Property.CEILING_SHININESS)) {
       // Ceiling shininess radio buttons bound to CEILING_SHININESS controller property
-      this.ceilingMattRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences, 
+      this.ceilingMattRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences,
           RoomPanel.class, "ceilingMattRadioButton.text"));
       this.ceilingMattRadioButton.addChangeListener(new ChangeListener() {
           public void stateChanged(ChangeEvent ev) {
@@ -368,10 +368,10 @@ public class RoomPanel extends JPanel implements DialogView {
             updateCeilingShininessRadioButtons(controller);
           }
         };
-      controller.addPropertyChangeListener(RoomController.Property.CEILING_SHININESS, 
+      controller.addPropertyChangeListener(RoomController.Property.CEILING_SHININESS,
           ceilingShininessListener);
-  
-      this.ceilingShinyRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences, 
+
+      this.ceilingShinyRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences,
           RoomPanel.class, "ceilingShinyRadioButton.text"));
       this.ceilingShinyRadioButton.addChangeListener(new ChangeListener() {
           public void stateChanged(ChangeEvent ev) {
@@ -380,20 +380,20 @@ public class RoomPanel extends JPanel implements DialogView {
             }
           }
         });
-      controller.addPropertyChangeListener(RoomController.Property.CEILING_SHININESS, 
+      controller.addPropertyChangeListener(RoomController.Property.CEILING_SHININESS,
           ceilingShininessListener);
-      
+
       ButtonGroup ceilingShininessButtonGroup = new ButtonGroup();
       ceilingShininessButtonGroup.add(this.ceilingMattRadioButton);
       ceilingShininessButtonGroup.add(this.ceilingShinyRadioButton);
       updateCeilingShininessRadioButtons(controller);
     }
-    
+
     if (controller.isPropertyEditable(RoomController.Property.SPLIT_SURROUNDING_WALLS)) {
       // Create visible check box bound to SPLIT_SURROUNDING_WALLS controller property
-      this.splitSurroundingWallsCheckBox = new JCheckBox(SwingTools.getLocalizedLabelText(preferences, 
+      this.splitSurroundingWallsCheckBox = new JCheckBox(SwingTools.getLocalizedLabelText(preferences,
           RoomPanel.class, "splitSurroundingWallsCheckBox.text"));
-      final String splitSurroundingWallsToolTip = 
+      final String splitSurroundingWallsToolTip =
           preferences.getLocalizedString(RoomPanel.class, "splitSurroundingWallsCheckBox.tooltip");
       PropertyChangeListener splitSurroundingWallsChangeListener = new PropertyChangeListener() {
         public void propertyChange(PropertyChangeEvent ev) {
@@ -415,10 +415,10 @@ public class RoomPanel extends JPanel implements DialogView {
           }
         });
     }
-    
+
     if (controller.isPropertyEditable(RoomController.Property.WALL_SIDES_PAINT)) {
       // Wall sides color and texture buttons bound to walls controller properties
-      this.wallSidesColorRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences, 
+      this.wallSidesColorRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences,
           RoomPanel.class, "wallSidesColorRadioButton.text"));
       this.wallSidesColorRadioButton.addChangeListener(new ChangeListener() {
           public void stateChanged(ChangeEvent e) {
@@ -428,32 +428,32 @@ public class RoomPanel extends JPanel implements DialogView {
             }
           }
         });
-      controller.addPropertyChangeListener(RoomController.Property.WALL_SIDES_PAINT, 
+      controller.addPropertyChangeListener(RoomController.Property.WALL_SIDES_PAINT,
           new PropertyChangeListener() {
             public void propertyChange(PropertyChangeEvent ev) {
               updateWallSidesRadioButtons(controller);
             }
           });
-  
+
       this.wallSidesColorButton = new ColorButton(preferences);
       this.wallSidesColorButton.setColor(controller.getWallSidesColor());
       this.wallSidesColorButton.setColorDialogTitle(preferences.getLocalizedString(
           RoomPanel.class, "wallSidesColorDialog.title"));
-      this.wallSidesColorButton.addPropertyChangeListener(ColorButton.COLOR_PROPERTY, 
+      this.wallSidesColorButton.addPropertyChangeListener(ColorButton.COLOR_PROPERTY,
           new PropertyChangeListener() {
             public void propertyChange(PropertyChangeEvent ev) {
               controller.setWallSidesColor(wallSidesColorButton.getColor());
             }
           });
-      controller.addPropertyChangeListener(RoomController.Property.WALL_SIDES_COLOR, 
+      controller.addPropertyChangeListener(RoomController.Property.WALL_SIDES_COLOR,
           new PropertyChangeListener() {
             public void propertyChange(PropertyChangeEvent ev) {
               wallSidesColorButton.setColor(controller.getWallSidesColor());
               selectSplitSurroundingWallsAtFirstChange();
             }
           });
-      
-      this.wallSidesTextureRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences, 
+
+      this.wallSidesTextureRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences,
           RoomPanel.class, "wallSidesTextureRadioButton.text"));
       this.wallSidesTextureRadioButton.addChangeListener(new ChangeListener() {
           public void stateChanged(ChangeEvent e) {
@@ -463,24 +463,24 @@ public class RoomPanel extends JPanel implements DialogView {
             }
           }
         });
-    
+
       this.wallSidesTextureComponent = (JComponent)controller.getWallSidesTextureController().getView();
-      controller.getWallSidesTextureController().addPropertyChangeListener(TextureChoiceController.Property.TEXTURE, 
+      controller.getWallSidesTextureController().addPropertyChangeListener(TextureChoiceController.Property.TEXTURE,
           new PropertyChangeListener() {
             public void propertyChange(PropertyChangeEvent ev) {
               selectSplitSurroundingWallsAtFirstChange();
             }
           });
-  
+
       ButtonGroup wallSidesButtonGroup = new ButtonGroup();
       wallSidesButtonGroup.add(this.wallSidesColorRadioButton);
       wallSidesButtonGroup.add(this.wallSidesTextureRadioButton);
       updateWallSidesRadioButtons(controller);
     }
-      
+
     if (controller.isPropertyEditable(RoomController.Property.WALL_SIDES_SHININESS)) {
       // Wall sides shininess radio buttons bound to WALL_SIDES_SHININESS controller property
-      this.wallSidesMattRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences, 
+      this.wallSidesMattRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences,
           RoomPanel.class, "wallSidesMattRadioButton.text"));
       this.wallSidesMattRadioButton.addChangeListener(new ChangeListener() {
           public void stateChanged(ChangeEvent ev) {
@@ -495,10 +495,10 @@ public class RoomPanel extends JPanel implements DialogView {
             updateWallSidesShininessRadioButtons(controller);
           }
         };
-      controller.addPropertyChangeListener(RoomController.Property.WALL_SIDES_SHININESS, 
+      controller.addPropertyChangeListener(RoomController.Property.WALL_SIDES_SHININESS,
           wallSidesShininessListener);
-  
-      this.wallSidesShinyRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences, 
+
+      this.wallSidesShinyRadioButton = new JRadioButton(SwingTools.getLocalizedLabelText(preferences,
           RoomPanel.class, "wallSidesShinyRadioButton.text"));
       this.wallSidesShinyRadioButton.addChangeListener(new ChangeListener() {
           public void stateChanged(ChangeEvent ev) {
@@ -508,19 +508,19 @@ public class RoomPanel extends JPanel implements DialogView {
             }
           }
         });
-      controller.addPropertyChangeListener(RoomController.Property.WALL_SIDES_SHININESS, 
+      controller.addPropertyChangeListener(RoomController.Property.WALL_SIDES_SHININESS,
           wallSidesShininessListener);
-      
+
       ButtonGroup wallSidesShininessButtonGroup = new ButtonGroup();
       wallSidesShininessButtonGroup.add(this.wallSidesMattRadioButton);
       wallSidesShininessButtonGroup.add(this.wallSidesShinyRadioButton);
       updateWallSidesShininessRadioButtons(controller);
-      
+
     }
-    
+
     if (controller.isPropertyEditable(RoomController.Property.WALL_SIDES_BASEBOARD)) {
       this.wallSidesBaseboardComponent = (JComponent)controller.getWallSidesBaseboardController().getView();
-      controller.getWallSidesBaseboardController().addPropertyChangeListener(BaseboardChoiceController.Property.VISIBLE, 
+      controller.getWallSidesBaseboardController().addPropertyChangeListener(BaseboardChoiceController.Property.VISIBLE,
           new PropertyChangeListener() {
             public void propertyChange(PropertyChangeEvent ev) {
               selectSplitSurroundingWallsAtFirstChange();
@@ -531,7 +531,7 @@ public class RoomPanel extends JPanel implements DialogView {
   }
 
   /**
-   * Updates floor color radio buttons. 
+   * Updates floor color radio buttons.
    */
   private void updateFloorColorRadioButtons(RoomController controller) {
     if (controller.getFloorPaint() == RoomController.RoomPaint.COLORED) {
@@ -544,7 +544,7 @@ public class RoomPanel extends JPanel implements DialogView {
   }
 
   /**
-   * Updates floor shininess radio buttons. 
+   * Updates floor shininess radio buttons.
    */
   private void updateFloorShininessRadioButtons(RoomController controller) {
     if (controller.getFloorShininess() == null) {
@@ -557,7 +557,7 @@ public class RoomPanel extends JPanel implements DialogView {
   }
 
   /**
-   * Updates ceiling color radio buttons. 
+   * Updates ceiling color radio buttons.
    */
   private void updateCeilingColorRadioButtons(RoomController controller) {
     if (controller.getCeilingPaint() == RoomController.RoomPaint.COLORED) {
@@ -570,7 +570,7 @@ public class RoomPanel extends JPanel implements DialogView {
   }
 
   /**
-   * Updates ceiling shininess radio buttons. 
+   * Updates ceiling shininess radio buttons.
    */
   private void updateCeilingShininessRadioButtons(RoomController controller) {
     if (controller.getCeilingShininess() == null) {
@@ -583,7 +583,7 @@ public class RoomPanel extends JPanel implements DialogView {
   }
 
   /**
-   * Updates wall sides radio buttons. 
+   * Updates wall sides radio buttons.
    */
   private void updateWallSidesRadioButtons(RoomController controller) {
     if (controller.getWallSidesPaint() == RoomController.RoomPaint.COLORED) {
@@ -596,7 +596,7 @@ public class RoomPanel extends JPanel implements DialogView {
   }
 
   /**
-   * Updates wall sides shininess radio buttons. 
+   * Updates wall sides shininess radio buttons.
    */
   private void updateWallSidesShininessRadioButtons(RoomController controller) {
     if (controller.getWallSidesShininess() == null) {
@@ -614,7 +614,7 @@ public class RoomPanel extends JPanel implements DialogView {
         && this.splitSurroundingWallsCheckBox.isEnabled()) {
       this.splitSurroundingWallsCheckBox.doClick();
       this.firstWallChange = false;
-    }    
+    }
   }
 
   /**
@@ -681,29 +681,30 @@ public class RoomPanel extends JPanel implements DialogView {
       }
     }
   }
-  
+
   /**
-   * Layouts panel components in panel with their labels. 
+   * Layouts panel components in panel with their labels.
    */
   private void layoutComponents(UserPreferences preferences) {
-    int labelAlignment = OperatingSystem.isMacOSX() 
+    int labelAlignment = OperatingSystem.isMacOSX()
         ? GridBagConstraints.LINE_END
         : GridBagConstraints.LINE_START;
+    int standardGap = Math.round(5 * SwingTools.getResolutionScale());
     // First row
     if (this.nameLabel != null || this.areaVisibleCheckBox != null) {
       JPanel nameAndAreaPanel = SwingTools.createTitledPanel(preferences.getLocalizedString(
           RoomPanel.class, "nameAndAreaPanel.title"));
       if (this.nameLabel != null) {
         nameAndAreaPanel.add(this.nameLabel, new GridBagConstraints(
-            0, 0, 1, 1, 0, 0, labelAlignment, 
-            GridBagConstraints.HORIZONTAL, new Insets(0, 8, 0, 5), 0, 0));
+            0, 0, 1, 1, 0, 0, labelAlignment,
+            GridBagConstraints.HORIZONTAL, new Insets(0, 8, 0, standardGap), 0, 0));
         nameAndAreaPanel.add(this.nameTextField, new GridBagConstraints(
-            1, 0, 1, 1, 1, 0, GridBagConstraints.LINE_START, 
+            1, 0, 1, 1, 1, 0, GridBagConstraints.LINE_START,
             GridBagConstraints.HORIZONTAL, new Insets(0, 0, 0, 10), 0, 0));
       }
       if (this.areaVisibleCheckBox != null) {
         nameAndAreaPanel.add(this.areaVisibleCheckBox, new GridBagConstraints(
-            2, 0, 1, 1, 1, 0, GridBagConstraints.LINE_START, 
+            2, 0, 1, 1, 1, 0, GridBagConstraints.LINE_START,
             GridBagConstraints.HORIZONTAL, new Insets(0, 0, 0, 0), 0, 0));
       }
       Insets rowInsets;
@@ -711,10 +712,10 @@ public class RoomPanel extends JPanel implements DialogView {
         // User smaller insets for Mac OS X 10.5
         rowInsets = new Insets(0, 0, 0, 0);
       } else {
-        rowInsets = new Insets(0, 0, 5, 0);
+        rowInsets = new Insets(0, 0, standardGap, 0);
       }
       add(nameAndAreaPanel, new GridBagConstraints(
-          0, 0, 3, 1, 0, 0, GridBagConstraints.LINE_START, 
+          0, 0, 3, 1, 0, 0, GridBagConstraints.LINE_START,
           GridBagConstraints.HORIZONTAL, rowInsets, 0, 0));
     }
     // Last row
@@ -722,29 +723,29 @@ public class RoomPanel extends JPanel implements DialogView {
       JPanel floorPanel = createVerticalTitledPanel(preferences.getLocalizedString(
           RoomPanel.class, "floorPanel.title"),
           new JComponent [][] {{this.floorVisibleCheckBox, null,
-                                this.floorColorRadioButton, this.floorColorButton, 
+                                this.floorColorRadioButton, this.floorColorButton,
                                 this.floorTextureRadioButton, this.floorTextureComponent},
                                 {this.floorMattRadioButton, this.floorShinyRadioButton}});
       add(floorPanel, new GridBagConstraints(
           0, 1, 1, 1, 1, 0, GridBagConstraints.NORTH,
           GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
-    }      
+    }
     if (this.ceilingVisibleCheckBox != null || this.ceilingColorRadioButton != null || this.ceilingMattRadioButton != null) {
       JPanel ceilingPanel = createVerticalTitledPanel(preferences.getLocalizedString(
           RoomPanel.class, "ceilingPanel.title"),
           new JComponent [][] {{this.ceilingVisibleCheckBox, null,
-                                this.ceilingColorRadioButton, this.ceilingColorButton, 
+                                this.ceilingColorRadioButton, this.ceilingColorButton,
                                 this.ceilingTextureRadioButton, this.ceilingTextureComponent},
                                 {this.ceilingMattRadioButton, this.ceilingShinyRadioButton}});
       add(ceilingPanel, new GridBagConstraints(
           1, 1, 1, 1, 1, 0, GridBagConstraints.NORTH,
           GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
-    }  
+    }
     if (this.wallSidesColorRadioButton != null || this.wallSidesMattRadioButton != null) {
       JPanel wallSidesPanel = createVerticalTitledPanel(preferences.getLocalizedString(
           RoomPanel.class, "wallSidesPanel.title"),
           new JComponent [][] {{this.splitSurroundingWallsCheckBox, null,
-                               this.wallSidesColorRadioButton, this.wallSidesColorButton, 
+                               this.wallSidesColorRadioButton, this.wallSidesColorButton,
                                this.wallSidesTextureRadioButton, this.wallSidesTextureComponent},
                                {this.wallSidesMattRadioButton, this.wallSidesShinyRadioButton}});
       add(wallSidesPanel, new GridBagConstraints(
@@ -762,33 +763,33 @@ public class RoomPanel extends JPanel implements DialogView {
           GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
     }
   }
-  
+
   private JPanel createVerticalTitledPanel(String title, JComponent [][] componentGroups) {
-    JPanel titledPanel = SwingTools.createTitledPanel(title);    
-    
+    JPanel titledPanel = SwingTools.createTitledPanel(title);
+
     int row = 0;
     for (int i = 0; i < componentGroups.length; i++) {
       JComponent [] components = componentGroups [i];
       for (int j = 0; j < components.length; j += 2) {
-        int bottomInset = j < components.length - 2  ? 2  : 0;      
+        int bottomInset = j < components.length - 2  ? Math.round(2 * SwingTools.getResolutionScale())  : 0;
         JComponent component = components [j];
         JComponent nextComponent = components [j + 1];
         if (component != null) {
           if (nextComponent != null) {
             titledPanel.add(component, new GridBagConstraints(
-                0, row, 1, 1, 1, 0, GridBagConstraints.LINE_START, 
-                GridBagConstraints.NONE,  new Insets(0, 0, bottomInset, 5), 0, 0));
+                0, row, 1, 1, 1, 0, GridBagConstraints.LINE_START,
+                GridBagConstraints.NONE,  new Insets(0, 0, bottomInset, Math.round(5 * SwingTools.getResolutionScale())), 0, 0));
             titledPanel.add(nextComponent, new GridBagConstraints(
-                1, row++, 1, 1, 1, 0, GridBagConstraints.LINE_START, 
+                1, row++, 1, 1, 1, 0, GridBagConstraints.LINE_START,
                 GridBagConstraints.HORIZONTAL, new Insets(0, 0, bottomInset, 0), 0, 0));
           } else {
             titledPanel.add(component, new GridBagConstraints(
-                0, row++, 2, 1, 1, 0, GridBagConstraints.LINE_START, 
+                0, row++, 2, 1, 1, 0, GridBagConstraints.LINE_START,
                 GridBagConstraints.HORIZONTAL, new Insets(0, 0, bottomInset, 0), 0, 0));
           }
         }
       }
-      
+
       if (i < componentGroups.length - 1) {
         // Add a separator between groups
         for (JComponent otherComponent : componentGroups [i + 1]) {
@@ -801,15 +802,15 @@ public class RoomPanel extends JPanel implements DialogView {
         }
       }
     }
-    
+
     return titledPanel;
   }
-  
+
   /**
-   * Displays this panel in a modal dialog box. 
+   * Displays this panel in a modal dialog box.
    */
   public void displayView(View parentView) {
-    if (SwingTools.showConfirmDialog((JComponent)parentView, 
+    if (SwingTools.showConfirmDialog((JComponent)parentView,
             this, this.dialogTitle, this.nameTextField) == JOptionPane.OK_OPTION
         && this.controller != null) {
       this.controller.modifyRooms();
