@@ -180,7 +180,9 @@ public class UserPreferencesPanel extends JPanel implements DialogView {
       this.languageComboBox.setSelectedItem(controller.getLanguage());
       this.languageComboBox.addItemListener(new ItemListener() {
           public void itemStateChanged(ItemEvent ev) {
-            controller.setLanguage((String)languageComboBox.getSelectedItem());
+            if (ev.getStateChange() == ItemEvent.SELECTED) {
+              controller.setLanguage((String)languageComboBox.getSelectedItem());
+            }
           }
         });
       controller.addPropertyChangeListener(UserPreferencesController.Property.LANGUAGE,
@@ -846,18 +848,18 @@ public class UserPreferencesPanel extends JPanel implements DialogView {
         ((UserPreferences)ev.getSource()).removePropertyChangeListener(
             UserPreferences.Property.SUPPORTED_LANGUAGES, this);
       } else {
-        JComboBox languageComboBox = userPreferencesPanel.languageComboBox;
+        final JComboBox languageComboBox = userPreferencesPanel.languageComboBox;
         List<String> oldSupportedLanguages = Arrays.asList((String [])ev.getOldValue());
         String [] supportedLanguages = (String [])ev.getNewValue();
         languageComboBox.setModel(new DefaultComboBoxModel(supportedLanguages));
+        languageComboBox.setSelectedItem(userPreferencesPanel.controller.getLanguage());
         // Select the first language added to supported languages
-        for (String language : supportedLanguages) {
+        for (final String language : supportedLanguages) {
           if (!oldSupportedLanguages.contains(language)) {
             languageComboBox.setSelectedItem(language);
-            return;
+            break;
           }
         }
-        languageComboBox.setSelectedItem(userPreferencesPanel.controller.getLanguage());
       }
     }
   }
@@ -1308,7 +1310,7 @@ public class UserPreferencesPanel extends JPanel implements DialogView {
   private static class AutoCommitLengthSpinner extends AutoCommitSpinner {
     public AutoCommitLengthSpinner(SpinnerModel model,
                                    final UserPreferencesController controller) {
-      super(model, controller.getUnit().getFormat());
+      super(model, controller.getUnit().getFormat(), false);
       // Add a listener to update format when unit changes
       controller.addPropertyChangeListener(UserPreferencesController.Property.UNIT,
         new PropertyChangeListener () {
