@@ -29,10 +29,8 @@ import java.util.Arrays;
 import java.util.Currency;
 import java.util.List;
 
-import javax.swing.undo.AbstractUndoableEdit;
 import javax.swing.undo.CannotRedoException;
 import javax.swing.undo.CannotUndoException;
-import javax.swing.undo.UndoableEdit;
 import javax.swing.undo.UndoableEditSupport;
 
 import com.eteks.sweethome3d.model.Content;
@@ -1643,14 +1641,13 @@ public class HomeFurnitureController implements Controller {
           paint, color, texture, modelMaterials, defaultShininess, shininess, visible, modelMirrored, lightPower);
       if (this.undoSupport != null) {
         List<Selectable> newSelection = this.home.getSelectedItems();
-        UndoableEdit undoableEdit = new FurnitureModificationUndoableEdit(
-            this.home, this.preferences, oldSelection, newSelection, modifiedFurniture,
-            name, nameVisible, description, price, removePrice, valueAddedTaxPercentage, removeValueAddedTaxPercentage, currency,
+        this.undoSupport.postEdit(new FurnitureModificationUndoableEdit(this.home, this.preferences,
+            oldSelection.toArray(new Selectable [oldSelection.size()]), newSelection.toArray(new Selectable [newSelection.size()]),
+            modifiedFurniture, name, nameVisible, description, price, removePrice, valueAddedTaxPercentage, removeValueAddedTaxPercentage, currency,
             x, y, elevation, angle, roll, pitch, horizontalAxis, basePlanItem,
             width, depth, height, proportional, modelTransformations,
             this.wallThickness, this.wallDistance, this.wallWidth, this.wallLeft, this.wallHeight, this.wallTop, this.sashes,
-            paint, color, texture, modelMaterials, defaultShininess, shininess, visible, modelMirrored, lightPower);
-        this.undoSupport.postEdit(undoableEdit);
+            paint, color, texture, modelMaterials, defaultShininess, shininess, visible, modelMirrored, lightPower));
       }
       if (name != null) {
         this.preferences.addAutoCompletionString("HomePieceOfFurnitureName", name);
@@ -1668,12 +1665,11 @@ public class HomeFurnitureController implements Controller {
    * Undoable edit for furniture modification. This class isn't anonymous to avoid
    * being bound to controller and its view.
    */
-  private static class FurnitureModificationUndoableEdit extends AbstractUndoableEdit {
+  private static class FurnitureModificationUndoableEdit extends LocalizedUndoableEdit {
     private final Home                        home;
-    private final UserPreferences             preferences;
     private final ModifiedPieceOfFurniture [] modifiedFurniture;
-    private final List<Selectable>            oldSelection;
-    private final List<Selectable>            newSelection;
+    private final Selectable []               oldSelection;
+    private final Selectable []               newSelection;
     private final String                      name;
     private final Boolean                     nameVisible;
     private final String                      description;
@@ -1711,11 +1707,14 @@ public class HomeFurnitureController implements Controller {
     private final float                       wallHeight;
     private final float                       wallTop;
     private final Sash []                     sashes;
+    private final float []                    widthsInPlan;
+    private final float []                    depthsInPlan;
+    private final float []                    heightsInPlan;
 
     private FurnitureModificationUndoableEdit(Home home,
                                               UserPreferences preferences,
-                                              List<Selectable> oldSelection,
-                                              List<Selectable> newSelection,
+                                              Selectable [] oldSelection,
+                                              Selectable [] newSelection,
                                               ModifiedPieceOfFurniture [] modifiedFurniture,
                                               String name, Boolean nameVisible, String description,
                                               BigDecimal price, boolean removePrice, BigDecimal valueAddedTaxPercentage, boolean removeValueAddedTaxPercenage, String currency,
@@ -1729,8 +1728,8 @@ public class HomeFurnitureController implements Controller {
                                               Boolean visible,
                                               Boolean modelMirrored,
                                               Float lightPower) {
+      super(preferences, HomeFurnitureController.class, "undoModifyFurnitureName");
       this.home = home;
-      this.preferences = preferences;
       this.oldSelection = oldSelection;
       this.newSelection = newSelection;
       this.modifiedFurniture = modifiedFurniture;
@@ -1771,13 +1770,23 @@ public class HomeFurnitureController implements Controller {
       this.visible = visible;
       this.modelMirrored = modelMirrored;
       this.lightPower = lightPower;
+      this.widthsInPlan = new float [modifiedFurniture.length];
+      this.depthsInPlan = new float [modifiedFurniture.length];
+      this.heightsInPlan = new float [modifiedFurniture.length];
+
+      for (int i = 0; i < modifiedFurniture.length; i++) {
+        HomePieceOfFurniture piece = modifiedFurniture[i].getPieceOfFurniture();
+        this.widthsInPlan [i] = piece.getWidthInPlan();
+        this.depthsInPlan [i] = piece.getDepthInPlan();
+        this.heightsInPlan [i] = piece.getHeightInPlan();
+      }
     }
 
     @Override
     public void undo() throws CannotUndoException {
       super.undo();
       undoModifyFurniture(this.modifiedFurniture);
-      this.home.setSelectedItems(this.oldSelection);
+      this.home.setSelectedItems(Arrays.asList(this.oldSelection));
     }
 
     @Override
@@ -1792,13 +1801,14 @@ public class HomeFurnitureController implements Controller {
           this.paint, this.color, this.texture, this.modelMaterials,
           this.defaultShininess, this.shininess,
           this.visible, this.modelMirrored, this.lightPower);
-      this.home.setSelectedItems(this.newSelection);
-    }
-
-    @Override
-    public String getPresentationName() {
-      return this.preferences.getLocalizedString(HomeFurnitureController.class,
-          "undoModifyFurnitureName");
+      // Force size in plan in case internal size update performed in PlanController can't be done again
+      for (int i = 0; i < this.modifiedFurniture.length; i++) {
+        HomePieceOfFurniture piece = this.modifiedFurniture[i].getPieceOfFurniture();
+        piece.setWidthInPlan(this.widthsInPlan [i]);
+        piece.setDepthInPlan(this.depthsInPlan [i]);
+        piece.setHeightInPlan(this.heightsInPlan [i]);
+      }
+      this.home.setSelectedItems(Arrays.asList(this.newSelection));
     }
   }
 
@@ -2002,6 +2012,9 @@ public class HomeFurnitureController implements Controller {
     private final float                width;
     private final float                depth;
     private final float                height;
+    private final float                widthInPlan;
+    private final float                depthInPlan;
+    private final float                heightInPlan;
     private final Transformation []    modelTransformations;
     private final Integer              color;
     private final HomeTexture          texture;
@@ -2028,6 +2041,9 @@ public class HomeFurnitureController implements Controller {
       this.width = piece.getWidth();
       this.depth = piece.getDepth();
       this.height = piece.getHeight();
+      this.widthInPlan = piece.getWidthInPlan();
+      this.depthInPlan = piece.getDepthInPlan();
+      this.heightInPlan = piece.getHeightInPlan();
       this.modelTransformations = piece.getModelTransformations();
       this.color = piece.getColor();
       this.texture = piece.getTexture();
@@ -2065,6 +2081,9 @@ public class HomeFurnitureController implements Controller {
         this.piece.setHeight(this.height);
         this.piece.setModelMirrored(this.modelMirrored);
       }
+      this.piece.setWidthInPlan(this.widthInPlan);
+      this.piece.setDepthInPlan(this.depthInPlan);
+      this.piece.setHeightInPlan(this.heightInPlan);
       this.piece.setModelTransformations(this.modelTransformations);
       if (this.piece.isTexturable()) {
         this.piece.setColor(this.color);
@@ -2152,6 +2171,8 @@ public class HomeFurnitureController implements Controller {
       this.groupFurnitureY = new float [groupFurniture.size()];
       this.groupFurnitureWidth = new float [groupFurniture.size()];
       this.groupFurnitureDepth = new float [groupFurniture.size()];
+      // Storing widthInPlan, depthInPlan and heightInPlan is useless
+      // because the size of a group containing horizontally rotated furniture can be only proportionally changed
       this.groupFurnitureColor = new Integer [groupFurniture.size()];
       this.groupFurnitureTexture = new HomeTexture [groupFurniture.size()];
       this.groupFurnitureShininess = new Float [groupFurniture.size()];
